/* Copyright (C) 2014 McAfee, Inc.  All rights reserved.*/
/*
triggers.sql is executed when this extension is installed in EPO.
The file is executed sequentially hence tables should created first and then
triggers should be created.
Before creating each trigger a check must be performed which ensures that the trigger is not already present.
This is done so as to make the sql reentrant.
Before writing any alter trigger statement for upgrades also check for existence/non existence so as to make sql reentrant.
the CREATE TRIGGER must be the first command in a batch in case of triggers, so the create trigger
ddl is send as argument to exec function instead. 
*/

if (dbo.SCOR_CHECK_TRIGGER_EXISTS ('TR_SCOR_SA_REQUEST_INSERT') = 0)
BEGIN
exec('CREATE TRIGGER [dbo].[TR_SCOR_SA_REQUEST_INSERT]
   ON  [dbo].[SCOR_SA_REQUEST]
   AFTER INSERT
AS 
BEGIN
select 1;
END')
END
GO

exec('ALTER TRIGGER [dbo].[TR_SCOR_SA_REQUEST_INSERT]
   ON  [dbo].[SCOR_SA_REQUEST]
   AFTER INSERT
AS 
BEGIN
  SET NOCOUNT ON


 INSERT INTO
     SCOR_SA_GROUPED_REQUEST([CHECKSUM], 
							[DETECTED_UTC], 
							[FILE_NAME], 
							[PREVALANCE], 
							[IS_MP_VIOLATION],
							[BINARY_INFO_ID],
							[ACTIVITY],
							[APPROVAL_STATUS_PENDING]
							) 
  SELECT DISTINCT
							i.CHECKSUM, 
							i.DETECTED_UTC, 
							CASE 
							WHEN i.EVENT_TYPE = ''ACTX_BLOCKED'' OR i.EVENT_TYPE = ''ACTX_INSTALL_PREVENTED'' OR i.IS_NETWORK_PATH = ''TRUE'' THEN i.OBJECT_NAME 
							ELSE i.BINARY_BASE_NAME END,
							0, 
							i.IS_MP_VIOLATION,
							i.BINARY_INFO_ID,
							i.ACTIVITY,
							1
  FROM
    Inserted i
       
  WHERE
    i.approval_status <>3 and i.approval_status <> 9 and i.approval_status <>12 and 
    NOT EXISTS ( 
      SELECT 1 
      FROM   SCOR_SA_GROUPED_REQUEST sagr
      WHERE  sagr.CHECKSUM   = i.checksum
	  and sagr.IS_MP_VIOLATION = i.IS_MP_VIOLATION		  
    )


  -- update all affected records at once
 UPDATE 
    SCOR_SA_GROUPED_REQUEST
  SET
    PREVALANCE = PREVALANCE + i.count
    
  FROM
    (
		SELECT
		  CHECKSUM,
		  IS_MP_VIOLATION,
		  COUNT(*) count
      
		FROM
		  Inserted
		where approval_status <>3 and approval_status <> 9 and approval_status <>12
		GROUP BY
		checksum,
		IS_MP_VIOLATION
     
    ) i 
    INNER JOIN SCOR_SA_GROUPED_REQUEST sagr ON 
      sagr.checksum   = i.checksum and 
	  sagr.IS_MP_VIOLATION = i.IS_MP_VIOLATION

  SET NOCOUNT OFF
END')
GO


if (dbo.SCOR_CHECK_TRIGGER_EXISTS ('TR_SCOR_SA_REQUEST_UPDATE') = 0)
BEGIN
exec('CREATE TRIGGER [dbo].[TR_SCOR_SA_REQUEST_UPDATE]
   ON  [dbo].[SCOR_SA_REQUEST]
   AFTER UPDATE
AS 
BEGIN
select 1;
END')
END
GO

exec('ALTER TRIGGER [dbo].[TR_SCOR_SA_REQUEST_UPDATE]
   ON  [dbo].[SCOR_SA_REQUEST]
   AFTER UPDATE
AS 
BEGIN
  SET NOCOUNT ON

  -- insert all missing checksum, IS_MP_VIOLATION rows which have been updated from previous unconfirmed status but not audit status.
  --for e.g. if approval_status for a request was 3(unconfirmed) and after update it changed to say 0(pending) but not 9(audit) or 12(auto approved at client)
  -- with cksum X, then if there was no entry for X in grouped_request, then insert it otherwise update the count.

 INSERT INTO
     SCOR_SA_GROUPED_REQUEST([CHECKSUM], 
							[DETECTED_UTC], 
							[FILE_NAME], 
							[PREVALANCE], 
							[IS_MP_VIOLATION],
							[BINARY_INFO_ID],
							[ACTIVITY],
							[APPROVAL_STATUS_PENDING]
							) 
  SELECT DISTINCT
							i.CHECKSUM, 
							i.DETECTED_UTC, 
							CASE 
							WHEN i.EVENT_TYPE = ''ACTX_BLOCKED'' OR i.EVENT_TYPE = ''ACTX_INSTALL_PREVENTED'' OR i.IS_NETWORK_PATH = ''TRUE'' THEN i.OBJECT_NAME 
							ELSE i.BINARY_BASE_NAME END,
							0, 
							i.IS_MP_VIOLATION,
							i.BINARY_INFO_ID,
							i.ACTIVITY,
							1
							
  FROM
    Inserted i inner join Deleted d on i.auto_id=d.auto_id
       
  WHERE
    d.approval_status =3 and (i.approval_status<>3 and i.approval_status <>9 and i.approval_status <>12) and 
    NOT EXISTS ( 
      SELECT 1 
      FROM   SCOR_SA_GROUPED_REQUEST sagr
      WHERE  sagr.CHECKSUM   = i.checksum
	  and sagr.IS_MP_VIOLATION = i.IS_MP_VIOLATION
    )

  -- update the prevalence count for all affected records at once
  UPDATE 
    SCOR_SA_GROUPED_REQUEST
  SET
    PREVALANCE   = PREVALANCE + updated_values.count
    
  FROM
    (
    SELECT
      i.checksum,
	  i.IS_MP_VIOLATION,
      COUNT(*) count
      
    FROM
       Inserted i inner join Deleted d on i.auto_id=d.auto_id
    WHERE
      d.approval_status =3 and (i.approval_status<>3 and i.approval_status <>9 and i.approval_status <>12) 
    GROUP BY
     i.checksum,
	 i.IS_MP_VIOLATION
    ) updated_values
    INNER JOIN SCOR_SA_GROUPED_REQUEST sagr ON 
      sagr.checksum   = updated_values.checksum 
	  and sagr.IS_MP_VIOLATION = updated_values.IS_MP_VIOLATION

  SET NOCOUNT OFF
END')
GO

if (dbo.SCOR_CHECK_TRIGGER_EXISTS ('TR_SCOR_SA_REQUEST_DELETE') = 0)
BEGIN
exec('CREATE TRIGGER [dbo].[TR_SCOR_SA_REQUEST_DELETE]
   ON  [dbo].[SCOR_SA_REQUEST]
   AFTER DELETE
AS 
BEGIN
select 1;
END')
END
GO

exec('ALTER TRIGGER [dbo].[TR_SCOR_SA_REQUEST_DELETE]
   ON  [dbo].[SCOR_SA_REQUEST]
   AFTER DELETE
AS 
BEGIN
  SET NOCOUNT ON

  -- update all affected records at once
  UPDATE 
    SCOR_SA_GROUPED_REQUEST
  SET
    PREVALANCE = PREVALANCE - i.count
    
  FROM
    (
    SELECT grouped_req_id, 
      COUNT(*) count
    FROM
      Deleted
    where approval_status <>3 and approval_status <>9 and approval_status <>12
    GROUP BY
    grouped_req_id
     
    ) i 
    INNER JOIN SCOR_SA_GROUPED_REQUEST sagr ON 
      sagr.auto_id = i.grouped_req_id
      
    -- delete all rows where prevalence <=0
	-- TODO : What about auditing, etc??
    DELETE from SCOR_SA_GROUPED_REQUEST where PREVALANCE <=0

  SET NOCOUNT OFF
END')
GO
