/* Copyright (C) 2018 McAfee, Inc.  All rights reserved. This file is created to upgrade scor_events table to big int*/
declare @sql nvarchar(max)

IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE DATA_TYPE = 'VARCHAR' AND TABLE_NAME = 'SCOR_BINARY_REPUTATION' AND COLUMN_NAME = 'SHA1')
BEGIN
	SET @sql ='ALTER TABLE SCOR_BINARY_REPUTATION
		ADD SHA1_N NVARCHAR(40),SHA2_N NVARCHAR(64),MD5_N  NVARCHAR(32)'
	
	EXEC(@sql)
	
	SET @sql='DECLARE @Rowcount INT = 1
    ,   @BatchSize INT = 10000
    ,   @StartingRecord BIGINT = (SELECT MIN(AUTO_ID) FROM SCOR_BINARY_REPUTATION);

    WHILE (@Rowcount > 0)   
		BEGIN
		    UPDATE SCOR_BINARY_REPUTATION
		        SET SHA1_N = SHA1,
				SHA2_N = SHA2,
				MD5_N = MD5
		    WHERE AUTO_ID BETWEEN @StartingRecord AND @StartingRecord + @BatchSize - 1;
		    SET @Rowcount = @@ROWCOUNT;
		    CHECKPOINT;
		    SELECT @StartingRecord += @BatchSize
		END'
	EXEC(@sql)
	
	-- DROP Constraints
	SET @sql='ALTER TABLE SCOR_BINARY_REPUTATION
	DROP CONSTRAINT UC_SCOR_BINARY_REPUTATION_SHA1';
	
	EXEC(@sql)
	
	SET @sql='ALTER TABLE SCOR_BINARY_REPUTATION
	DROP COLUMN SHA1,SHA2,MD5'

	EXEC(@sql)
	
	EXEC sp_rename 'SCOR_BINARY_REPUTATION.SHA1_N', 'SHA1', 'COLUMN';

	EXEC sp_rename 'SCOR_BINARY_REPUTATION.SHA2_N', 'SHA2', 'COLUMN';

	EXEC sp_rename 'SCOR_BINARY_REPUTATION.MD5_N', 'MD5', 'COLUMN';
	
	-- RECREATE INDEX
	SET @sql='ALTER TABLE SCOR_BINARY_REPUTATION 
		ADD  CONSTRAINT UC_SCOR_BINARY_REPUTATION_SHA1 UNIQUE NONCLUSTERED 
		(
			SHA1 ASC
		)WITH 
		(PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, 
			IGNORE_DUP_KEY = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, 
			ALLOW_PAGE_LOCKS = ON, FILLFACTOR = 80)'
	
	EXEC(@sql)
END
GO

declare @sql nvarchar(max)
IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE DATA_TYPE = 'VARCHAR' AND TABLE_NAME = 'SCOR_CERT_REPUTATION' AND COLUMN_NAME = 'CERT_HASH')
BEGIN
	SET @sql ='ALTER TABLE SCOR_CERT_REPUTATION
			ADD CERT_HASH_N NVARCHAR(64),PUBLIC_KEY_HASH_N NVARCHAR(64)'
	
	EXEC(@sql)
	
	SET @sql='DECLARE @Rowcount INT = 1
	    ,   @BatchSize INT = 10000
	    ,   @StartingRecord BIGINT = (SELECT MIN(AUTO_ID) FROM SCOR_CERT_REPUTATION);

			WHILE (@Rowcount > 0)   
			BEGIN
			    UPDATE SCOR_CERT_REPUTATION
			        SET CERT_HASH_N = CERT_HASH,
					PUBLIC_KEY_HASH_N = PUBLIC_KEY_HASH
			    WHERE AUTO_ID BETWEEN @StartingRecord AND @StartingRecord + @BatchSize - 1;
			    SET @Rowcount = @@ROWCOUNT;
			    CHECKPOINT;
			    SELECT @StartingRecord += @BatchSize
			END'
	EXEC(@sql)
	
	SET @sql='ALTER TABLE SCOR_CERT_REPUTATION
		DROP COLUMN CERT_HASH, PUBLIC_KEY_HASH';
	
	EXEC(@sql)
	
	EXEC sp_rename 'SCOR_CERT_REPUTATION.CERT_HASH_N', 'CERT_HASH', 'COLUMN'
	
	EXEC sp_rename 'SCOR_CERT_REPUTATION.PUBLIC_KEY_HASH_N', 'PUBLIC_KEY_HASH', 'COLUMN';
END
GO

declare @sql nvarchar(max)
IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE DATA_TYPE = 'VARCHAR' AND TABLE_NAME = 'SCOR_CERTIFICATE' AND COLUMN_NAME = 'ISSUER_SHA1')
BEGIN
	SET @sql ='ALTER TABLE SCOR_CERTIFICATE
		ADD ISSUER_SHA1_N NVARCHAR(40),
		PUBLIC_KEY_HASH_N NVARCHAR(64),
		PUBLIC_KEY_HASH_ALGO_N NVARCHAR(30),
		PUBLIC_KEY_ALGO_N NVARCHAR(30),
		CERT_HASH_N NVARCHAR(64),
		CERT_HASH_ALGO_N NVARCHAR(30),
		CERT_VERSION_N NVARCHAR(30),
		SIGNATURE_ALGO_N NVARCHAR(50),
		SIGNATURE_HASH_ALGO_N NVARCHAR(50),
		SERIAL_NUMBER_N NVARCHAR(250);'
	
	EXEC(@sql)
	
	SET @sql='DECLARE @Rowcount INT = 1
	    ,   @BatchSize INT = 10000
	    ,   @StartingRecord BIGINT =  (SELECT MIN(ID) FROM SCOR_CERTIFICATE);
		set @Rowcount=1;
		set @StartingRecord=1;
		WHILE (@Rowcount > 0)   
		BEGIN
		    UPDATE SCOR_CERTIFICATE
		        SET ISSUER_SHA1_N = ISSUER_SHA1,
				PUBLIC_KEY_HASH_N = PUBLIC_KEY_HASH,
				PUBLIC_KEY_HASH_ALGO_N = PUBLIC_KEY_HASH_ALGO,
				PUBLIC_KEY_ALGO_N = PUBLIC_KEY_ALGO,
				CERT_HASH_N = CERT_HASH,
				CERT_HASH_ALGO_N = CERT_HASH_ALGO,
				CERT_VERSION_N = CERT_VERSION,
				SIGNATURE_ALGO_N = SIGNATURE_ALGO,
				SIGNATURE_HASH_ALGO_N = SIGNATURE_HASH_ALGO,
				SERIAL_NUMBER_N = SERIAL_NUMBER
		    WHERE ID BETWEEN @StartingRecord AND @StartingRecord + @BatchSize - 1;
		    SET @Rowcount = @@ROWCOUNT;
		    CHECKPOINT;
		    SELECT @StartingRecord += @BatchSize
	    END'
	EXEC(@sql)
	
	SET @sql='ALTER TABLE SCOR_CERTIFICATE DROP CONSTRAINT SCOR_UNIQUE_CERT_HASH';
	
	EXEC(@sql)
	
	SET @sql='ALTER TABLE SCOR_CERTIFICATE
		DROP COLUMN ISSUER_SHA1,PUBLIC_KEY_HASH,PUBLIC_KEY_HASH_ALGO,PUBLIC_KEY_ALGO,CERT_HASH,
		CERT_HASH_ALGO,CERT_VERSION,SIGNATURE_ALGO,SIGNATURE_HASH_ALGO,SERIAL_NUMBER';
	
	EXEC(@sql)
	
	EXEC sp_rename 'SCOR_CERTIFICATE.ISSUER_SHA1_N', 'ISSUER_SHA1', 'COLUMN';
	
	EXEC sp_rename 'SCOR_CERTIFICATE.PUBLIC_KEY_HASH_N', 'PUBLIC_KEY_HASH', 'COLUMN';
	
	EXEC sp_rename 'SCOR_CERTIFICATE.PUBLIC_KEY_HASH_ALGO_N', 'PUBLIC_KEY_HASH_ALGO', 'COLUMN';
	
	EXEC sp_rename 'SCOR_CERTIFICATE.PUBLIC_KEY_ALGO_N', 'PUBLIC_KEY_ALGO', 'COLUMN';
	
	EXEC sp_rename 'SCOR_CERTIFICATE.CERT_HASH_N', 'CERT_HASH', 'COLUMN';
	
	EXEC sp_rename 'SCOR_CERTIFICATE.CERT_HASH_ALGO_N', 'CERT_HASH_ALGO', 'COLUMN';
	
	EXEC sp_rename 'SCOR_CERTIFICATE.CERT_VERSION_N', 'CERT_VERSION', 'COLUMN';
	
	EXEC sp_rename 'SCOR_CERTIFICATE.SIGNATURE_ALGO_N', 'SIGNATURE_ALGO', 'COLUMN';
	
	EXEC sp_rename 'SCOR_CERTIFICATE.SIGNATURE_HASH_ALGO_N', 'SIGNATURE_HASH_ALGO', 'COLUMN';
	
	EXEC sp_rename 'SCOR_CERTIFICATE.SERIAL_NUMBER_N', 'SERIAL_NUMBER', 'COLUMN';

	SET @sql='ALTER TABLE SCOR_CERTIFICATE ADD  CONSTRAINT SCOR_UNIQUE_CERT_HASH UNIQUE NONCLUSTERED 
			(
				CERT_HASH ASC
			)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, IGNORE_DUP_KEY = OFF, 
			ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)'
	
	EXEC(@sql)
	
END
GO

declare @sql nvarchar(max)
IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE DATA_TYPE = 'VARCHAR' AND TABLE_NAME = 'SCOR_COMMON_BINARY_INFO' AND COLUMN_NAME = 'BINARY_SHA1')
BEGIN
	SET @sql ='ALTER TABLE SCOR_COMMON_BINARY_INFO
		ADD BINARY_SHA1_N NVARCHAR(64),
		BINARY_MD5_N NVARCHAR(32),
		BINARY_SHA256_N NVARCHAR(64);'
	
	EXEC(@sql)
	
	SET @sql='DECLARE @Rowcount INT = 1
	    ,   @BatchSize INT = 10000
	    ,   @StartingRecord BIGINT =  (SELECT MIN(AUTO_ID) FROM SCOR_COMMON_BINARY_INFO);
		WHILE (@Rowcount > 0)   
		BEGIN
		    UPDATE SCOR_COMMON_BINARY_INFO
		        SET BINARY_SHA1_N = BINARY_SHA1,
				BINARY_MD5_N = BINARY_MD5,
				BINARY_SHA256_N = BINARY_SHA256
		    WHERE AUTO_ID BETWEEN @StartingRecord AND @StartingRecord + @BatchSize - 1;
		    SET @Rowcount = @@ROWCOUNT;
		    CHECKPOINT;
		    SELECT @StartingRecord += @BatchSize
		END'
	EXEC(@sql)
	
	IF EXISTS (SELECT *  FROM sys.indexes  WHERE name='SCOR_IDX_COMMON_BINARY_INFO_BINARY_SHA1' AND object_id = OBJECT_ID('SCOR_COMMON_BINARY_INFO'))
	BEGIN
		SET @sql='DROP INDEX SCOR_IDX_COMMON_BINARY_INFO_BINARY_SHA1 ON SCOR_COMMON_BINARY_INFO';
		EXEC(@sql)
	END

	IF EXISTS (SELECT *  FROM sys.indexes  WHERE name='SCOR_IDX_COMMON_BINARY_INFO_BINARY_SHA256' AND object_id = OBJECT_ID('SCOR_COMMON_BINARY_INFO'))
	BEGIN
		SET @sql='DROP INDEX SCOR_IDX_COMMON_BINARY_INFO_BINARY_SHA256 ON SCOR_COMMON_BINARY_INFO';
		EXEC(@sql)
	END
	
	SET @sql='ALTER TABLE SCOR_COMMON_BINARY_INFO DROP COLUMN BINARY_SHA1,BINARY_MD5,BINARY_SHA256';
	
	EXEC(@sql)
	
	EXEC sp_rename 'SCOR_COMMON_BINARY_INFO.BINARY_SHA1_N', 'BINARY_SHA1', 'COLUMN';

	EXEC sp_rename 'SCOR_COMMON_BINARY_INFO.BINARY_MD5_N', 'BINARY_MD5', 'COLUMN';

	EXEC sp_rename 'SCOR_COMMON_BINARY_INFO.BINARY_SHA256_N', 'BINARY_SHA256', 'COLUMN';
	
	SET @sql='CREATE NONCLUSTERED INDEX SCOR_IDX_COMMON_BINARY_INFO_BINARY_SHA1 ON SCOR_COMMON_BINARY_INFO
	(
		BINARY_SHA1 ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)'
	
	EXEC(@sql)
	
	SET @sql='CREATE NONCLUSTERED INDEX SCOR_IDX_COMMON_BINARY_INFO_BINARY_SHA256 ON SCOR_COMMON_BINARY_INFO
	(
		BINARY_SHA256 ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)'
	
	EXEC(@sql)
	
END
GO

declare @sql nvarchar(max)
IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE DATA_TYPE = 'VARCHAR' AND TABLE_NAME = 'SCOR_COMMON_BINARY_INFO' AND COLUMN_NAME = 'BINARY_SHA1')
BEGIN
	SET @sql ='ALTER TABLE SCOR_COMMON_BINARY_INFO
		ADD BINARY_SHA1_N NVARCHAR(64),
		BINARY_MD5_N NVARCHAR(32),
		BINARY_SHA256_N NVARCHAR(64);'
	
	EXEC(@sql)
	
	SET @sql='DECLARE @Rowcount INT = 1
	    ,   @BatchSize INT = 10000
	    ,   @StartingRecord BIGINT =  (SELECT MIN(AUTO_ID) FROM SCOR_COMMON_BINARY_INFO);
		WHILE (@Rowcount > 0)   
		BEGIN
		    UPDATE SCOR_COMMON_BINARY_INFO
		        SET BINARY_SHA1_N = BINARY_SHA1,
				BINARY_MD5_N = BINARY_MD5,
				BINARY_SHA256_N = BINARY_SHA256
		    WHERE AUTO_ID BETWEEN @StartingRecord AND @StartingRecord + @BatchSize - 1;
		    SET @Rowcount = @@ROWCOUNT;
		    CHECKPOINT;
		    SELECT @StartingRecord += @BatchSize
		END'
	EXEC(@sql)
	
	IF EXISTS (SELECT *  FROM sys.indexes  WHERE name='SCOR_IDX_COMMON_BINARY_INFO_BINARY_SHA1' AND object_id = OBJECT_ID('SCOR_COMMON_BINARY_INFO'))
	BEGIN
		SET @sql='DROP INDEX SCOR_IDX_COMMON_BINARY_INFO_BINARY_SHA1 ON SCOR_COMMON_BINARY_INFO';
		EXEC(@sql)
	END
	
	IF EXISTS (SELECT *  FROM sys.indexes  WHERE name='SCOR_IDX_COMMON_BINARY_INFO_BINARY_SHA256' AND object_id = OBJECT_ID('SCOR_COMMON_BINARY_INFO'))
	BEGIN
		SET @sql='DROP INDEX SCOR_IDX_COMMON_BINARY_INFO_BINARY_SHA256 ON SCOR_COMMON_BINARY_INFO';
		EXEC(@sql)
	END
	
	SET @sql='ALTER TABLE SCOR_COMMON_BINARY_INFO DROP COLUMN BINARY_SHA1,BINARY_MD5,BINARY_SHA256';
	
	EXEC(@sql)
	
	EXEC sp_rename 'SCOR_COMMON_BINARY_INFO.BINARY_SHA1_N', 'BINARY_SHA1', 'COLUMN';

	EXEC sp_rename 'SCOR_COMMON_BINARY_INFO.BINARY_MD5_N', 'BINARY_MD5', 'COLUMN';

	EXEC sp_rename 'SCOR_COMMON_BINARY_INFO.BINARY_SHA256_N', 'BINARY_SHA256', 'COLUMN';
	
	SET @sql='CREATE NONCLUSTERED INDEX SCOR_IDX_COMMON_BINARY_INFO_BINARY_SHA1 ON SCOR_COMMON_BINARY_INFO
	(
		BINARY_SHA1 ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)'
	
	EXEC(@sql)
	
	SET @sql='CREATE NONCLUSTERED INDEX SCOR_IDX_COMMON_BINARY_INFO_BINARY_SHA256 ON SCOR_COMMON_BINARY_INFO
	(
		BINARY_SHA256 ASC
	)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)'
	
	EXEC(@sql)
	
END
GO

declare @sql nvarchar(max)
IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE DATA_TYPE = 'VARCHAR' AND TABLE_NAME = 'SCOR_EVENTS' AND COLUMN_NAME = 'EVT_FILE_SHA1')
BEGIN
	SET @sql ='ALTER TABLE SCOR_EVENTS
		ADD EVT_FILE_SHA1_N NVARCHAR(40),
		EVT_FILE_MD5_N NVARCHAR(32),
		EVT_FILE_TYPE_N NVARCHAR(30),
		EVT_PROCESS_SHA1_N NVARCHAR(40),
		EVT_PROCESS_MD5_N NVARCHAR(32),
		EVT_FILE_SHA256_N NVARCHAR(64),
		EVT_PROCESS_SHA256_N NVARCHAR(64);'
	
	EXEC(@sql)
	
	SET @sql='DECLARE @Rowcount INT = 1
		    ,   @BatchSize INT = 10000
		    ,   @StartingRecord BIGINT = (SELECT MIN(AutoID) FROM SCOR_EVENTS);
		
		WHILE (@Rowcount > 0)   
		BEGIN
		    UPDATE SCOR_EVENTS
		        SET EVT_FILE_SHA1_N = EVT_FILE_SHA1,
				EVT_FILE_MD5_N = EVT_FILE_MD5,
				EVT_FILE_TYPE_N = EVT_FILE_TYPE,
				EVT_PROCESS_SHA1_N = EVT_PROCESS_SHA1,
				EVT_PROCESS_MD5_N = EVT_PROCESS_MD5,
				EVT_FILE_SHA256_N = EVT_FILE_SHA256,
				EVT_PROCESS_SHA256_N = EVT_PROCESS_SHA256
		    WHERE AutoID BETWEEN @StartingRecord AND @StartingRecord + @BatchSize - 1;
		    SET @Rowcount = @@ROWCOUNT;
		    CHECKPOINT;
		    SELECT @StartingRecord += @BatchSize
		END'
	EXEC(@sql)
	
	
	SET @sql='ALTER TABLE SCOR_EVENTS
		DROP COLUMN EVT_FILE_SHA1,
					EVT_FILE_MD5,
					EVT_FILE_TYPE,
					EVT_PROCESS_SHA1,
					EVT_PROCESS_MD5,
					EVT_FILE_SHA256,
					EVT_PROCESS_SHA256;'
	
	EXEC(@sql)
	
	EXEC sp_rename 'SCOR_EVENTS.EVT_FILE_SHA1_N', 'EVT_FILE_SHA1', 'COLUMN';
	
	EXEC sp_rename 'SCOR_EVENTS.EVT_FILE_MD5_N', 'EVT_FILE_MD5', 'COLUMN';
	
	EXEC sp_rename 'SCOR_EVENTS.EVT_FILE_TYPE_N', 'EVT_FILE_TYPE', 'COLUMN';
	
	EXEC sp_rename 'SCOR_EVENTS.EVT_PROCESS_SHA1_N', 'EVT_PROCESS_SHA1', 'COLUMN';
	
	EXEC sp_rename 'SCOR_EVENTS.EVT_PROCESS_MD5_N', 'EVT_PROCESS_MD5', 'COLUMN';
	
	EXEC sp_rename 'SCOR_EVENTS.EVT_FILE_SHA256_N', 'EVT_FILE_SHA256', 'COLUMN';
	
	EXEC sp_rename 'SCOR_EVENTS.EVT_PROCESS_SHA256_N', 'EVT_PROCESS_SHA256', 'COLUMN';
END
GO

declare @sql nvarchar(max)
IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE DATA_TYPE = 'VARCHAR' AND TABLE_NAME = 'SCOR_INV_BINARIES' AND COLUMN_NAME = 'BINARY_SHA1')
BEGIN
	SET @sql ='ALTER TABLE SCOR_INV_BINARIES
			ADD BINARY_SHA1_N NVARCHAR(64),
			BINARY_MD5_N NVARCHAR(32);'
	
	EXEC(@sql)
	
	SET @sql='DECLARE @Rowcount INT = 1
		    ,   @BatchSize INT = 10000
		    ,   @StartingRecord BIGINT =  (SELECT MIN(BINARY_ID) FROM SCOR_INV_BINARIES);
		WHILE (@Rowcount > 0)   
		BEGIN
		    UPDATE SCOR_INV_BINARIES
		        SET BINARY_SHA1_N = BINARY_SHA1,
				BINARY_MD5_N = BINARY_MD5
		    WHERE BINARY_ID BETWEEN @StartingRecord AND @StartingRecord + @BatchSize - 1;
		    SET @Rowcount = @@ROWCOUNT;
		    CHECKPOINT;
		    SELECT @StartingRecord += @BatchSize
		END'
	EXEC(@sql)
	
	IF EXISTS (SELECT *  FROM sys.indexes  WHERE name='SCOR_IDX_INV_BINARIES_BINARY_SHA1_INCLUDE_BASE_NAME_APP_ID' AND object_id = OBJECT_ID('SCOR_INV_BINARIES'))
	BEGIN
		SET @sql='DROP INDEX SCOR_IDX_INV_BINARIES_BINARY_SHA1_INCLUDE_BASE_NAME_APP_ID ON SCOR_INV_BINARIES'
		EXEC(@sql)
	END
	
	
	IF EXISTS (SELECT *  FROM sys.indexes  WHERE name='SCOR_INV_BINARIES_BINARY_SHA1' AND object_id = OBJECT_ID('SCOR_INV_BINARIES'))
	BEGIN
		SET @sql='DROP INDEX SCOR_INV_BINARIES_BINARY_SHA1 ON SCOR_INV_BINARIES'
		EXEC(@sql)
	END

	IF EXISTS (SELECT *  FROM sys.indexes  WHERE name='SCOR_INV_BINARIES_BINARY_MD5' AND object_id = OBJECT_ID('SCOR_INV_BINARIES'))
	BEGIN
		SET @sql='DROP INDEX SCOR_INV_BINARIES_BINARY_MD5 ON SCOR_INV_BINARIES'
		EXEC(@sql)
	END

	IF EXISTS (SELECT *  FROM sys.indexes  WHERE name='SCOR_IDX_INV_BINARIES_BINARY_SHA1_INCLUDE_BASE_NAME_APP_ID_IS_CTL_OVERRDN' AND object_id = OBJECT_ID('SCOR_INV_BINARIES'))
	BEGIN
		SET @sql='DROP INDEX SCOR_IDX_INV_BINARIES_BINARY_SHA1_INCLUDE_BASE_NAME_APP_ID_IS_CTL_OVERRDN ON SCOR_INV_BINARIES'
		EXEC(@sql)
	END

	SET @sql='ALTER TABLE SCOR_INV_BINARIES
		DROP COLUMN BINARY_SHA1,BINARY_MD5;'
	EXEC(@sql)
	
	EXEC sp_rename 'SCOR_INV_BINARIES.BINARY_SHA1_N', 'BINARY_SHA1', 'COLUMN';
	
	EXEC sp_rename 'SCOR_INV_BINARIES.BINARY_MD5_N', 'BINARY_MD5', 'COLUMN';
	
	SET @sql='CREATE NONCLUSTERED INDEX SCOR_IDX_INV_BINARIES_BINARY_SHA1_INCLUDE_BASE_NAME_APP_ID ON SCOR_INV_BINARIES
		(
			BINARY_SHA1 ASC
		)
		INCLUDE ( 	BINARY_BASE_NAME,
			APP_ID) WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, FILLFACTOR = 80)'
	
	EXEC(@sql)

	SET @sql='CREATE NONCLUSTERED INDEX SCOR_INV_BINARIES_BINARY_MD5 ON SCOR_INV_BINARIES
		(
			BINARY_MD5 ASC
		)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, FILLFACTOR = 80)'
	
	EXEC(@sql)

	SET @sql='CREATE NONCLUSTERED INDEX SCOR_INV_BINARIES_BINARY_SHA1 ON SCOR_INV_BINARIES
		(
			BINARY_SHA1 ASC
			)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)'
	EXEC(@sql)


	IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'SCOR_INV_BINARIES' AND COLUMN_NAME = 'IS_CUSTOM_TRUST_LEVEL_OVERRIDDEN')
	BEGIN	

		SET @sql='CREATE NONCLUSTERED INDEX SCOR_IDX_INV_BINARIES_BINARY_SHA1_INCLUDE_BASE_NAME_APP_ID_IS_CTL_OVERRDN ON SCOR_INV_BINARIES
			(
				BINARY_SHA1 ASC
			)
			INCLUDE ( 	BINARY_BASE_NAME,APP_ID,IS_CUSTOM_TRUST_LEVEL_OVERRIDDEN) WITH 
			(PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)'
	    EXEC(@sql)
	END

END
GO

declare @sql nvarchar(max)
IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE DATA_TYPE = 'VARCHAR' AND TABLE_NAME = 'SCOR_OBSERVATION_FILTERS' AND COLUMN_NAME = 'OBSERVATION_TYPE')
BEGIN
	SET @sql ='ALTER TABLE SCOR_OBSERVATION_FILTERS
		ADD OBSERVATION_TYPE_N NVARCHAR(256)'
	
	EXEC(@sql)
	
	SET @sql='DECLARE @Rowcount INT = 1
		    ,   @BatchSize INT = 10000
		    ,   @StartingRecord BIGINT =  (SELECT MIN(AUTO_ID) FROM SCOR_OBSERVATION_FILTERS);
		WHILE (@Rowcount > 0)   
		BEGIN
		    UPDATE SCOR_OBSERVATION_FILTERS
		        SET OBSERVATION_TYPE_N = OBSERVATION_TYPE
		    WHERE AUTO_ID BETWEEN @StartingRecord AND @StartingRecord + @BatchSize - 1;
		    SET @Rowcount = @@ROWCOUNT;
		    CHECKPOINT;
		    SELECT @StartingRecord += @BatchSize
		END'
	EXEC(@sql)
	
	
	SET @sql='ALTER TABLE SCOR_OBSERVATION_FILTERS DROP COLUMN OBSERVATION_TYPE;'
	EXEC(@sql)
	

	EXEC sp_rename 'SCOR_OBSERVATION_FILTERS.OBSERVATION_TYPE_N', 'OBSERVATION_TYPE', 'COLUMN'
	
	
END
GO

declare @sql nvarchar(max)
IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE DATA_TYPE = 'VARCHAR' AND TABLE_NAME = 'SCOR_OBSERVATION_STATISTICS' AND COLUMN_NAME = 'BINARY_INFO')
BEGIN
	SET @sql ='ALTER TABLE SCOR_OBSERVATION_STATISTICS
		ADD BINARY_INFO_N NVARCHAR(max)'
	
	EXEC(@sql)
	
	SET @sql='DECLARE @Rowcount INT = 1
		    ,   @BatchSize INT = 10000
		    ,   @StartingRecord BIGINT =  (SELECT MIN(AUTO_ID) FROM SCOR_OBSERVATION_STATISTICS);
		WHILE (@Rowcount > 0)   
		BEGIN
		    UPDATE SCOR_OBSERVATION_STATISTICS
		        SET BINARY_INFO_N = BINARY_INFO
		    WHERE AUTO_ID BETWEEN @StartingRecord AND @StartingRecord + @BatchSize - 1;
		    SET @Rowcount = @@ROWCOUNT;
		    CHECKPOINT;
		    SELECT @StartingRecord += @BatchSize
		END'
	EXEC(@sql)
	
	
	SET @sql='ALTER TABLE SCOR_OBSERVATION_STATISTICS DROP COLUMN BINARY_INFO;'
	EXEC(@sql)
	

	EXEC sp_rename 'SCOR_OBSERVATION_STATISTICS.BINARY_INFO_N', 'BINARY_INFO', 'COLUMN'
	
END
GO

declare @sql nvarchar(max)
IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE DATA_TYPE = 'VARCHAR' AND TABLE_NAME = 'SCOR_OBSERVATIONS' AND COLUMN_NAME = 'BINARY_CKSUM')
BEGIN
	SET @sql ='ALTER TABLE SCOR_OBSERVATIONS
		ADD BINARY_CKSUM_N NVARCHAR(64),
		CERTIFICATE_N NVARCHAR(max),
		DENY_REASON_N NVARCHAR(1024),
		EXPLOIT_TYPE_N NVARCHAR(1024),
		OBSERVATION_TYPE_N NVARCHAR(256);'
	
	EXEC(@sql)
	
	SET @sql='DECLARE @Rowcount INT = 1
		    ,   @BatchSize INT = 10000
		    ,   @StartingRecord BIGINT =  (SELECT MIN(AUTO_ID) FROM SCOR_OBSERVATIONS);
		WHILE (@Rowcount > 0)   
		BEGIN
		    UPDATE SCOR_OBSERVATIONS
		        SET BINARY_CKSUM_N = BINARY_CKSUM,
				CERTIFICATE_N = CERTIFICATE,
				DENY_REASON_N = DENY_REASON,
				EXPLOIT_TYPE_N = EXPLOIT_TYPE,
				OBSERVATION_TYPE_N = OBSERVATION_TYPE
		    WHERE AUTO_ID BETWEEN @StartingRecord AND @StartingRecord + @BatchSize - 1;
		    SET @Rowcount = @@ROWCOUNT;
		    CHECKPOINT;
		    SELECT @StartingRecord += @BatchSize
		END'
	EXEC(@sql)
	
	IF EXISTS (SELECT *  FROM sys.indexes  WHERE name='SCOR_OBSERVATIONS_SIMILAR_OBSERVATIONS_INDEX' AND object_id = OBJECT_ID('SCOR_OBSERVATIONS'))
	BEGIN
		SET @sql='DROP INDEX SCOR_OBSERVATIONS_SIMILAR_OBSERVATIONS_INDEX ON SCOR_OBSERVATIONS'
		EXEC(@sql)
	END

	IF EXISTS (SELECT *  FROM sys.indexes  WHERE name='SCOR_OBSERVATIONS_DETECTED_UTC_INDEX' AND object_id = OBJECT_ID('SCOR_OBSERVATIONS'))
	BEGIN
		SET @sql='DROP INDEX SCOR_OBSERVATIONS_DETECTED_UTC_INDEX ON SCOR_OBSERVATIONS'
		EXEC(@sql)
	END

	SET @sql='ALTER TABLE SCOR_OBSERVATIONS DROP COLUMN BINARY_CKSUM,CERTIFICATE,DENY_REASON,EXPLOIT_TYPE,OBSERVATION_TYPE;'
	EXEC(@sql)

	EXEC sp_rename 'SCOR_OBSERVATIONS.BINARY_CKSUM_N', 'BINARY_CKSUM', 'COLUMN';
	
	EXEC sp_rename 'SCOR_OBSERVATIONS.CERTIFICATE_N', 'CERTIFICATE', 'COLUMN';
	
	EXEC sp_rename 'SCOR_OBSERVATIONS.DENY_REASON_N', 'DENY_REASON', 'COLUMN';
	
	EXEC sp_rename 'SCOR_OBSERVATIONS.EXPLOIT_TYPE_N', 'EXPLOIT_TYPE', 'COLUMN';
	
	EXEC sp_rename 'SCOR_OBSERVATIONS.OBSERVATION_TYPE_N', 'OBSERVATION_TYPE', 'COLUMN';
	
	SET @sql='CREATE NONCLUSTERED INDEX SCOR_OBSERVATIONS_SIMILAR_OBSERVATIONS_INDEX ON SCOR_OBSERVATIONS
		(
			IS_ROOT ASC,
			APPROVAL_STATUS ASC,
			OBSERVATION_TYPE ASC
		)
		INCLUDE ( 	BINARY_CKSUM,
			BINARY_NAME,
			ACTIVEX_NAME,
			AGENTGUID) WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)'
	EXEC(@sql)

	SET @sql='CREATE NONCLUSTERED INDEX SCOR_OBSERVATIONS_DETECTED_UTC_INDEX ON SCOR_OBSERVATIONS
		(
			DETECTED_UTC ASC
		)
		INCLUDE ( 	AGENTGUID,
			APPROVAL_STATUS,
			IS_ROOT,
			BINARY_NAME,
			ACTIVEX_NAME,
			OBSERVATION_TYPE) WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)'
	
	EXEC(@sql)
	
END
GO

declare @sql nvarchar(max)
IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE DATA_TYPE = 'VARCHAR' AND TABLE_NAME = 'SCOR_ROLLUP_EVENTS' AND COLUMN_NAME = 'EVT_FILE_SHA1')
BEGIN
	SET @sql ='ALTER TABLE SCOR_ROLLUP_EVENTS
		ADD EVT_FILE_SHA1_N NVARCHAR(40),
		EVT_FILE_MD5_N NVARCHAR(32),
		EVT_FILE_TYPE_N NVARCHAR(30),
		EVT_PROCESS_SHA1_N NVARCHAR(40),
		EVT_PROCESS_MD5_N NVARCHAR(32),
		EVT_FILE_SHA256_N NVARCHAR(64),
		EVT_PROCESS_SHA256_N NVARCHAR(64);'
	
	EXEC(@sql)
	
	SET @sql='DECLARE @Rowcount INT = 1
		    ,   @BatchSize INT = 10000
		    ,   @StartingRecord BIGINT =  (SELECT MIN(AutoID) FROM SCOR_ROLLUP_EVENTS);
		WHILE (@Rowcount > 0)   
		BEGIN
		    UPDATE SCOR_ROLLUP_EVENTS
		        SET EVT_FILE_SHA1_N = EVT_FILE_SHA1,
				EVT_FILE_MD5_N = EVT_FILE_MD5,
				EVT_FILE_TYPE_N = EVT_FILE_TYPE,
				EVT_PROCESS_SHA1_N = EVT_PROCESS_SHA1,
				EVT_PROCESS_MD5_N = EVT_PROCESS_MD5,
				EVT_FILE_SHA256_N = EVT_FILE_SHA256,
				EVT_PROCESS_SHA256_N = EVT_PROCESS_SHA256
		    WHERE AutoID BETWEEN @StartingRecord AND @StartingRecord + @BatchSize - 1;
		    SET @Rowcount = @@ROWCOUNT;
		    CHECKPOINT;
		    SELECT @StartingRecord += @BatchSize
		END'
	EXEC(@sql)
	
	
	SET @sql='ALTER TABLE SCOR_ROLLUP_EVENTS DROP COLUMN EVT_FILE_SHA1,EVT_FILE_MD5,EVT_FILE_TYPE,EVT_PROCESS_SHA1,EVT_PROCESS_MD5,EVT_FILE_SHA256,EVT_PROCESS_SHA256;'
	EXEC(@sql)
	
	
	EXEC sp_rename 'SCOR_ROLLUP_EVENTS.EVT_FILE_SHA1_N', 'EVT_FILE_SHA1', 'COLUMN';

	EXEC sp_rename 'SCOR_ROLLUP_EVENTS.EVT_FILE_MD5_N', 'EVT_FILE_MD5', 'COLUMN';

	EXEC sp_rename 'SCOR_ROLLUP_EVENTS.EVT_FILE_TYPE_N', 'EVT_FILE_TYPE', 'COLUMN';

	EXEC sp_rename 'SCOR_ROLLUP_EVENTS.EVT_PROCESS_SHA1_N', 'EVT_PROCESS_SHA1', 'COLUMN';

	EXEC sp_rename 'SCOR_ROLLUP_EVENTS.EVT_PROCESS_MD5_N', 'EVT_PROCESS_MD5', 'COLUMN';

	EXEC sp_rename 'SCOR_ROLLUP_EVENTS.EVT_FILE_SHA256_N', 'EVT_FILE_SHA256', 'COLUMN';

	EXEC sp_rename 'SCOR_ROLLUP_EVENTS.EVT_PROCESS_SHA256_N', 'EVT_PROCESS_SHA256', 'COLUMN';
		
END
GO

declare @sql nvarchar(max)
IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE DATA_TYPE = 'VARCHAR' AND TABLE_NAME = 'SCOR_SA_GROUPED_REQUEST' AND COLUMN_NAME = 'CHECKSUM')
BEGIN
	SET @sql ='ALTER TABLE SCOR_SA_GROUPED_REQUEST
		ADD CHECKSUM_N NVARCHAR(40),
		BINARY_SHA256_N NVARCHAR(64);'
	
	EXEC(@sql)
	
	SET @sql='DECLARE @Rowcount INT = 1
		    ,   @BatchSize INT = 10000
		    ,   @StartingRecord BIGINT =  (SELECT MIN(AUTO_ID) FROM SCOR_SA_GROUPED_REQUEST);
		WHILE (@Rowcount > 0)   
		BEGIN
		    UPDATE SCOR_SA_GROUPED_REQUEST
		        SET CHECKSUM_N = CHECKSUM,
				BINARY_SHA256_N = BINARY_SHA256
		    WHERE AUTO_ID BETWEEN @StartingRecord AND @StartingRecord + @BatchSize - 1;
		    SET @Rowcount = @@ROWCOUNT;
		    CHECKPOINT;
		    SELECT @StartingRecord += @BatchSize
		END'
	EXEC(@sql)
	
	IF EXISTS (SELECT *  FROM sys.indexes  WHERE name='SCOR_SA_GROUPED_REQUEST_CHECKSUM' AND object_id = OBJECT_ID('SCOR_SA_GROUPED_REQUEST'))
	BEGIN
		SET @sql='DROP INDEX SCOR_SA_GROUPED_REQUEST_CHECKSUM ON SCOR_SA_GROUPED_REQUEST'
		EXEC(@sql)
	END

	IF EXISTS (SELECT *  FROM sys.indexes  WHERE name='SCOR_SA_GROUPED_REQUEST_BINARY_SHA256' AND object_id = OBJECT_ID('SCOR_SA_GROUPED_REQUEST'))
	BEGIN
		SET @sql='DROP INDEX SCOR_SA_GROUPED_REQUEST_BINARY_SHA256 ON SCOR_SA_GROUPED_REQUEST'
		EXEC(@sql)
	END
	
	SET @sql='ALTER TABLE SCOR_SA_GROUPED_REQUEST DROP COLUMN CHECKSUM,BINARY_SHA256;'
	EXEC(@sql)
	
	EXEC sp_rename 'SCOR_SA_GROUPED_REQUEST.CHECKSUM_N', 'CHECKSUM', 'COLUMN';

	EXEC sp_rename 'SCOR_SA_GROUPED_REQUEST.BINARY_SHA256_N', 'BINARY_SHA256', 'COLUMN';
	
	SET @sql='CREATE NONCLUSTERED INDEX SCOR_SA_GROUPED_REQUEST_CHECKSUM ON SCOR_SA_GROUPED_REQUEST
		(
			CHECKSUM ASC
		)
		INCLUDE ( 	IS_MP_VIOLATION) WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)'
	EXEC(@sql)

	SET @sql='CREATE NONCLUSTERED INDEX SCOR_SA_GROUPED_REQUEST_BINARY_SHA256 ON SCOR_SA_GROUPED_REQUEST
		(
			BINARY_SHA256 ASC
		)
		INCLUDE ( 	IS_MP_VIOLATION) WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON)'
	EXEC(@sql)
	
END
GO

declare @sql nvarchar(max)
IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE DATA_TYPE = 'VARCHAR' AND TABLE_NAME = 'SCOR_SA_REQUEST' AND COLUMN_NAME = 'EVENT_TYPE')
BEGIN
	SET @sql ='ALTER TABLE SCOR_SA_REQUEST
		ADD EVENT_TYPE_N NVARCHAR(64),
		USER_ACTION_N NVARCHAR(64),
		CHECKSUM_N NVARCHAR(40),
		BINARY_SHA256_N NVARCHAR(64);'
	
	EXEC(@sql)
	
	SET @sql='DECLARE @Rowcount INT = 1
		    ,   @BatchSize INT = 10000
		    ,   @StartingRecord BIGINT =  (SELECT MIN(AUTO_ID) FROM SCOR_SA_REQUEST);
		WHILE (@Rowcount > 0)   
		BEGIN
		    UPDATE SCOR_SA_REQUEST
		        SET EVENT_TYPE_N = EVENT_TYPE,
				USER_ACTION_N = USER_ACTION,
				CHECKSUM_N = CHECKSUM,
				BINARY_SHA256_N = BINARY_SHA256
		    WHERE AUTO_ID BETWEEN @StartingRecord AND @StartingRecord + @BatchSize - 1;
		    SET @Rowcount = @@ROWCOUNT;
		    CHECKPOINT;
		    SELECT @StartingRecord += @BatchSize
		END'
	EXEC(@sql)
	
	SET @sql='ALTER TABLE SCOR_SA_REQUEST DROP COLUMN EVENT_TYPE,USER_ACTION,CHECKSUM,BINARY_SHA256;'
	EXEC(@sql)
	

	EXEC sp_rename 'SCOR_SA_REQUEST.EVENT_TYPE_N', 'EVENT_TYPE', 'COLUMN';
	
	EXEC sp_rename 'SCOR_SA_REQUEST.USER_ACTION_N', 'USER_ACTION', 'COLUMN';
	
	EXEC sp_rename 'SCOR_SA_REQUEST.CHECKSUM_N', 'CHECKSUM', 'COLUMN';
	
	EXEC sp_rename 'SCOR_SA_REQUEST.BINARY_SHA256_N', 'BINARY_SHA256', 'COLUMN';
		
END
GO

declare @sql nvarchar(max)
IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE DATA_TYPE = 'VARCHAR' AND TABLE_NAME = 'SCOR_SA_RULES' AND COLUMN_NAME = 'EVENT_TYPE')
BEGIN
	SET @sql ='ALTER TABLE SCOR_SA_RULES
		ADD EVENT_TYPE_N NVARCHAR(400),
		SA_ACTION_N NVARCHAR(256),
		CHECKSUM_N NVARCHAR(40),
		BINARY_SHA256_N NVARCHAR(64);'
	
	EXEC(@sql)
	
	SET @sql='DECLARE @Rowcount INT = 1
		    ,   @BatchSize INT = 10000
		    ,   @StartingRecord BIGINT =  (SELECT MIN(AUTO_ID) FROM SCOR_SA_RULES);
		WHILE (@Rowcount > 0)   
		BEGIN
		    UPDATE SCOR_SA_RULES
		        SET EVENT_TYPE_N = EVENT_TYPE,
				SA_ACTION_N = SA_ACTION,
				CHECKSUM_N = CHECKSUM,
				BINARY_SHA256_N = BINARY_SHA256
		    WHERE AUTO_ID BETWEEN @StartingRecord AND @StartingRecord + @BatchSize - 1;
		    SET @Rowcount = @@ROWCOUNT;
		    CHECKPOINT;
		    SELECT @StartingRecord += @BatchSize
		END'
	EXEC(@sql)
	
	IF EXISTS (SELECT *  FROM sys.indexes  WHERE name='SCOR_SA_RULE_GROUPED_REQ_ID' AND object_id = OBJECT_ID('SCOR_SA_RULES'))
	BEGIN
		SET @sql='DROP INDEX SCOR_SA_RULE_GROUPED_REQ_ID ON SCOR_SA_RULES;'
		EXEC(@sql)
	END

	SET @sql='ALTER TABLE SCOR_SA_RULES DROP COLUMN EVENT_TYPE,SA_ACTION,CHECKSUM,BINARY_SHA256;'
	EXEC(@sql)

	EXEC sp_rename 'SCOR_SA_RULES.EVENT_TYPE_N', 'EVENT_TYPE', 'COLUMN';

	EXEC sp_rename 'SCOR_SA_RULES.SA_ACTION_N', 'SA_ACTION', 'COLUMN';
	
	EXEC sp_rename 'SCOR_SA_RULES.CHECKSUM_N', 'CHECKSUM', 'COLUMN';
	
	EXEC sp_rename 'SCOR_SA_RULES.BINARY_SHA256_N', 'BINARY_SHA256', 'COLUMN';

	SET @sql='CREATE NONCLUSTERED INDEX SCOR_SA_RULE_GROUPED_REQ_ID ON SCOR_SA_RULES
		(
			GROUPED_REQ_ID ASC
		)
		INCLUDE ( 	AUTO_ID,
			EVENT_TYPE,
			SA_ACTION,
			CHECKSUM,
			BINARY_INFO_ID,
			BINARY_PATH,
			IS_NETWORK_PATH,
			BINARY_SHA256) WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, SORT_IN_TEMPDB = OFF, DROP_EXISTING = OFF, ONLINE = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, FILLFACTOR = 80)'
	EXEC(@sql)
	
END
GO

declare @sql nvarchar(max)
IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE DATA_TYPE = 'VARCHAR' AND TABLE_NAME = 'SCOR_TASK_CLEANUP_REGISTRY' AND COLUMN_NAME = 'OWNING_CLASS_KEY')
BEGIN
	SET @sql ='ALTER TABLE SCOR_TASK_CLEANUP_REGISTRY
		ADD OWNING_CLASS_KEY_N NVARCHAR(256);'
	
	EXEC(@sql)
	
	SET @sql='DECLARE @Rowcount INT = 1
		    ,   @BatchSize INT = 10000
		    ,   @StartingRecord BIGINT =  (SELECT MIN(ID) FROM SCOR_TASK_CLEANUP_REGISTRY);
		WHILE (@Rowcount > 0)   
		BEGIN
		    UPDATE SCOR_TASK_CLEANUP_REGISTRY
		        SET OWNING_CLASS_KEY_N = OWNING_CLASS_KEY
		    WHERE ID BETWEEN @StartingRecord AND @StartingRecord + @BatchSize - 1;
		    SET @Rowcount = @@ROWCOUNT;
		    CHECKPOINT;
		    SELECT @StartingRecord += @BatchSize
		END'
	EXEC(@sql)
	
	SET @sql='ALTER TABLE SCOR_TASK_CLEANUP_REGISTRY DROP COLUMN OWNING_CLASS_KEY;'
	EXEC(@sql)
	
	EXEC sp_rename 'SCOR_TASK_CLEANUP_REGISTRY.OWNING_CLASS_KEY_N', 'OWNING_CLASS_KEY', 'COLUMN';
	
END
GO

-----------------------------------
-- VIEWS UPDATES
------------------------------------


IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'SCOR_VW_EVENT_FEEDBACK_DATA')
BEGIN
	exec sp_refreshview 'SCOR_VW_EVENT_FEEDBACK_DATA';
END
GO


IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'SCOR_VW_BINARY_HOST_STATS')
BEGIN
	exec sp_refreshview 'SCOR_VW_BINARY_HOST_STATS';
END
GO

declare @sql nvarchar(max)
IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'SCOR_VW_CHANGE_MANAGEMENT_COMPLIANCE')
BEGIN
	SET @sql='ALTER VIEW SCOR_VW_CHANGE_MANAGEMENT_COMPLIANCE AS
		SELECT se.AutoID,se.DETECTEDUTC,se.AGENTGUID,se.HOST_NAME,se.EVT_ORIG_USER_NAME,se.EVT_DISPLAY_KEY,se.EVT_PROG_NAME,se.EVT_OBJECT,se.RECON_TIX,CASE WHEN RECON_FLAG=2 OR RECON_FLAG=3 OR RECON_FLAG=6 THEN N''Authorized'' WHEN RECON_FLAG=5 OR RECON_FLAG=10 THEN N''Unauthorized'' END RECON_STATUS
		FROM SCOR_EVENTS se where RECON_FLAG in (2,3,5,6,10);'
	EXEC(@sql)
END
GO

IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'SCOR_VW_INV_BINARIES')
BEGIN
	exec sp_refreshview 'SCOR_VW_INV_BINARIES';
END
GO

declare @sql nvarchar(max)
IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'SCOR_VW_INVENTORY')
BEGIN
	SET @sql='ALTER VIEW SCOR_VW_INVENTORY AS
		SELECT APPS.APP_ID, APPS.APP_NAME, APPS.APP_VERSION, APPS.APP_VENDOR, APPS.APP_DISP_NAME, APPS.APP_DISP_VERSION, APPS.APP_DISP_VENDOR, APPS.CUSTOM_TRUST_LEVEL APP_CUSTOM_TRUST_LEVEL,
		BIN.BINARY_ID, BIN.BINARY_EMBED_NAME, BIN.BINARY_EMBED_VERSION, BIN.BINARY_EMBED_APP_NAME, BIN.BINARY_EMBED_APP_VERSION,
		BIN.BINARY_EMBED_APP_VENDOR, BIN.BINARY_BASE_NAME, BIN.BINARY_SHA1,BIN.BINARY_SHA256, 
		BIN.BINARY_SIZE, BIN.BINARY_TYPE, BIN.IS_INSTALLER, BIN.HAS_CERTS,
		BIN.FIRST_SEEN_TIME, BIN.FIRST_SEEN_HOST,
		CASE WHEN BIN.APP_ID IS NULL THEN BIN.BINARY_ID ELSE BIN.APP_ID END TEMP_ID,
		CASE WHEN BIN.APP_ID IS NULL THEN N''scor.topSystemsWithBadApps.da.otherBinaries'' ELSE N''scor.topSystemsWithBadApps.da.applications'' END CATEGORY,
		REP.GTI_SCORE_MAPPED, REP.GTI_TRUST_LEVEL, REP.EFFECTIVE_LEVEL, 
		REP.GTI_IS_INSTALLER, REP.GTI_IS_SYSTEM_FILE,
		ASSOC.ID, ASSOC.BINARY_PATH, ASSOC.EXECUTION_STATUS, ASSOC.FETCH_TIME LAST_UPDATED_TIME, ASSOC.IS_ALLOWED_BY_CHECKSUM,
		ASSOC.IS_ALLOWED_BY_CERT, ASSOC.IS_ALLOWED_BY_NAME, ASSOC.IS_ALLOWED_BY_TRUSTED_PATH,
		ASSOC.IS_SOLIDIFIED, ASSOC.IS_UPDATER, ASSOC.IS_SYSTEM_FILE, ASSOC.AGENTGUID, scorProp.INVENTORY_FETCH_TIME 
		FROM SCOR_INV_SYSTEM_PROPERTIES scorProp
		INNER JOIN SCOR_VW_HOST_BINARY_ASSOC_WITH_PATH ASSOC on (scorProp.AGENTGUID = ASSOC.AGENTGUID)
		LEFT OUTER JOIN SCOR_INV_BINARIES BIN ON (ASSOC.BINARY_ID = BIN.BINARY_ID)
		LEFT OUTER JOIN SCOR_BINARY_REPUTATION REP ON (BIN.BINARY_REPUTATION_ID = REP.AUTO_ID)
		LEFT OUTER JOIN SCOR_INV_APPS APPS ON (BIN.APP_ID = APPS.APP_ID);'
	EXEC(@sql)
END
GO

declare @sql nvarchar(max)
IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'SCOR_VW_LICENSE')
BEGIN
	SET @sql='ALTER VIEW SCOR_VW_LICENSE AS
		SELECT  ParentID,
			AgentGUID,
			N''license_change_control'' as ''LicenseType''
			FROM SCOR_VW_PROPERTIES_AGENTGUID
			WHERE license_change_control is NOT NULL
			UNION
		SELECT  ParentID,AgentGUID, N''license_runtime_control'' as ''LicenseType''
			FROM SCOR_VW_PROPERTIES_AGENTGUID
			WHERE license_runtime_control is NOT NULL'
	EXEC(@sql)
END
GO

declare @sql nvarchar(max)
IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'SCOR_VW_MANIFEST_CHANGES_METHOD1_VIEW')
BEGIN
	SET @sql='ALTER VIEW SCOR_VW_MANIFEST_CHANGES_METHOD1_VIEW AS
		SELECT max(PROD.autoID) AUTOID, PROD.HOST_NAME PRODUCTION_SERVER, PROD.AGENTGUID, TEST.HOST_NAME TEST_SERVER, PROD.EVT_NAME, PROD.EVT_DISPLAY_KEY,
		PROD.EVT_OBJECT, PROD.RECON_TIX TICKET_ID, TIX.STAGING_TICKET, N''changesInManifest'' CHANGE_SUMMARY
		FROM SCOR_EVENTS PROD
		INNER JOIN SCOR_RECON_TICKET2 TIX ON PROD.RECON_TIX = TIX.TICKET_ID AND TIX.STAGING_TICKET IS NOT NULL
		INNER JOIN SCOR_EVENTS TEST ON TIX.STAGING_TICKET = TEST.RECON_TIX AND PROD.EVT_NAME = TEST.EVT_NAME AND ISNULL(PROD.EVT_OBJECT,'''') = ISNULL(TEST.EVT_OBJECT,'''')
		GROUP BY PROD.HOST_NAME, PROD.AGENTGUID, TEST.HOST_NAME, PROD.EVT_NAME, PROD.EVT_DISPLAY_KEY, PROD.EVT_OBJECT, PROD.RECON_TIX, TIX.STAGING_TICKET
		UNION
		SELECT max(PROD.autoID) AUTOID, PROD.HOST_NAME PRODUCTION_SERVER, PROD.AGENTGUID, TEST.HOST_NAME TEST_SERVER, PROD.EVT_NAME, PROD.EVT_DISPLAY_KEY, PROD.EVT_OBJECT,
		PROD.RECON_TIX TICKET_ID, TIX.STAGING_TICKET ,N''changesNotInManifest'' CHANGE_SUMMARY
		FROM SCOR_EVENTS PROD
		INNER JOIN dbo.SCOR_RECON_TICKET2 TIX ON PROD.RECON_TIX = TIX.TICKET_ID AND TIX.STAGING_TICKET IS NOT NULL
		INNER JOIN dbo.SCOR_EVENTS TEST ON TIX.STAGING_TICKET = TEST.RECON_TIX
		GROUP BY PROD.HOST_NAME, PROD.AGENTGUID, TEST.HOST_NAME, PROD.EVT_NAME, PROD.EVT_DISPLAY_KEY, PROD.EVT_OBJECT, PROD.RECON_TIX, TIX.STAGING_TICKET
		EXCEPT
		SELECT max(PROD.autoID) AUTOID, PROD.HOST_NAME PRODUCTION_SERVER, PROD.AGENTGUID, TEST.HOST_NAME TEST_SERVER, PROD.EVT_NAME, PROD.EVT_DISPLAY_KEY, PROD.EVT_OBJECT,
		PROD.RECON_TIX TICKET_ID, TIX.STAGING_TICKET, N''changesNotInManifest'' CHANGE_SUMMARY
		FROM SCOR_EVENTS PROD
		INNER JOIN SCOR_RECON_TICKET2 TIX ON PROD.RECON_TIX = TIX.TICKET_ID AND TIX.STAGING_TICKET IS NOT NULL
		INNER JOIN SCOR_EVENTS TEST ON TIX.STAGING_TICKET = TEST.RECON_TIX AND PROD.EVT_NAME = TEST.EVT_NAME AND ISNULL(PROD.EVT_OBJECT,'''') = ISNULL(TEST.EVT_OBJECT,'''')
		GROUP BY PROD.HOST_NAME, PROD.AGENTGUID, TEST.HOST_NAME, PROD.EVT_NAME, PROD.EVT_DISPLAY_KEY, PROD.EVT_OBJECT, PROD.RECON_TIX, TIX.STAGING_TICKET
		UNION
		SELECT max(TEST.autoID) AUTOID, PROD.HOST_NAME PRODUCTION_SERVER, PROD.AGENTGUID, TEST.HOST_NAME TEST_SERVER, TEST.EVT_NAME, TEST.EVT_DISPLAY_KEY,
		TEST.EVT_OBJECT, PROD.RECON_TIX TICKET_ID, TIX.STAGING_TICKET ,N''changesNotFromManifest'' CHANGE_SUMMARY
		FROM SCOR_EVENTS TEST
		INNER JOIN SCOR_RECON_TICKET2 TIX ON TEST.RECON_TIX = TIX.STAGING_TICKET AND TIX.STAGING_TICKET IS NOT NULL
		INNER JOIN SCOR_EVENTS PROD ON TIX.TICKET_ID = PROD.RECON_TIX
		GROUP BY PROD.HOST_NAME, PROD.AGENTGUID, TEST.HOST_NAME, TEST.EVT_NAME, TEST.EVT_DISPLAY_KEY, TEST.EVT_OBJECT, PROD.RECON_TIX, TIX.STAGING_TICKET
		EXCEPT
		SELECT max(TEST.autoID) AUTOID, PROD.HOST_NAME PRODUCTION_SERVER, PROD.AGENTGUID, TEST.HOST_NAME TEST_SERVER, PROD.EVT_NAME, PROD.EVT_DISPLAY_KEY,
		PROD.EVT_OBJECT, PROD.RECON_TIX TICKET_ID, TIX.STAGING_TICKET, N''changesNotFromManifest'' CHANGE_SUMMARY
		FROM SCOR_EVENTS PROD
		INNER JOIN SCOR_RECON_TICKET2 TIX ON PROD.RECON_TIX = TIX.TICKET_ID AND TIX.STAGING_TICKET IS NOT NULL
		INNER JOIN SCOR_EVENTS TEST ON TIX.STAGING_TICKET = TEST.RECON_TIX AND PROD.EVT_NAME = TEST.EVT_NAME AND ISNULL(PROD.EVT_OBJECT,'''') = ISNULL(TEST.EVT_OBJECT,'''')
		GROUP BY PROD.HOST_NAME, PROD.AGENTGUID, TEST.HOST_NAME, PROD.EVT_NAME, PROD.EVT_DISPLAY_KEY, PROD.EVT_OBJECT, PROD.RECON_TIX, TIX.STAGING_TICKET;'
	EXEC(@sql)
END
GO

declare @sql nvarchar(max)
IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'SCOR_VW_MANIFEST_CHANGES_METHOD2_VIEW')
BEGIN
	SET @sql='ALTER VIEW SCOR_VW_MANIFEST_CHANGES_METHOD2_VIEW AS
		SELECT PROD.AUTOID, PROD.ID, PROD.HOST_NAME PRODUCTION_SERVER, PROD.AGENTGUID, TEST.HOST_NAME TEST_SERVER, PROD.EVT_NAME, PROD.EVT_DISPLAY_KEY,
		PROD.EVT_OBJECT , PROD.RECON_TIX TICKET_ID, TEST.RECON_TIX STAGING_TICKET, N''changesInManifest'' CHANGE_SUMMARY
		FROM
		(SELECT AUTOiD, row_number() over (partition by HOST_NAME,EVT_NAME,EVT_OBJECT,RECON_TIX order by HOST_NAME,EVT_NAME,EVT_OBJECT,RECON_TIX) ID,S.HOST_NAME,S.AGENTGUID, S.EVT_NAME,S.EVT_DISPLAY_KEY, S.EVT_OBJECT, S.RECON_TIX FROM dbo.SCOR_EVENTS S
		) PROD
		INNER JOIN SCOR_RECON_TICKET2 TIX ON PROD.RECON_TIX = TIX.TICKET_ID AND TIX.STAGING_TICKET IS NOT NULL
		INNER JOIN
		(SELECT AUTOiD, row_number() over (partition by HOST_NAME,EVT_NAME,EVT_OBJECT,RECON_TIX order by HOST_NAME,EVT_NAME,EVT_OBJECT,RECON_TIX) ID,S.HOST_NAME, S.EVT_NAME,S.EVT_DISPLAY_KEY, S.EVT_OBJECT, S.RECON_TIX FROM dbo.SCOR_EVENTS S) TEST
		ON PROD.ID=TEST.ID AND PROD.EVT_NAME = TEST.EVT_NAME AND ISNULL(PROD.EVT_OBJECT,'''') = ISNULL(TEST.EVT_OBJECT,'''') AND TIX.STAGING_TICKET = TEST.RECON_TIX
		UNION
		SELECT DISTINCT PROD.AUTOID, PROD.ID, PROD.HOST_NAME PRODUCTION_SERVER, PROD.AGENTGUID, TEST.HOST_NAME TEST_SERVER, PROD.EVT_NAME, PROD.EVT_DISPLAY_KEY,
		PROD.EVT_OBJECT , PROD.RECON_TIX TICKET_ID, TEST.RECON_TIX STAGING_TICKET, N''changesNotInManifest'' CHANGE_SUMMARY
		FROM
		(SELECT AUTOiD, row_number() over (partition by HOST_NAME,EVT_NAME,EVT_OBJECT,RECON_TIX order by HOST_NAME,EVT_NAME,EVT_OBJECT,RECON_TIX) ID,S.HOST_NAME, S.AGENTGUID, S.EVT_NAME,S.EVT_DISPLAY_KEY, S.EVT_OBJECT, S.RECON_TIX FROM dbo.SCOR_EVENTS S
		) PROD
		INNER JOIN SCOR_RECON_TICKET2 TIX ON PROD.RECON_TIX = TIX.TICKET_ID AND TIX.STAGING_TICKET IS NOT NULL
		INNER JOIN
		(SELECT DISTINCT row_number() over (partition by HOST_NAME,EVT_NAME,EVT_OBJECT,RECON_TIX order by HOST_NAME,EVT_NAME,EVT_OBJECT,RECON_TIX) ID,S.HOST_NAME, S.RECON_TIX FROM dbo.SCOR_EVENTS S) TEST
		ON TIX.STAGING_TICKET = TEST.RECON_TIX
		EXCEPT
		SELECT PROD.AUTOID, PROD.ID ,PROD.HOST_NAME PRODUCTION_SERVER, PROD.AGENTGUID, TEST.HOST_NAME TEST_SERVER, PROD.EVT_NAME, PROD.EVT_DISPLAY_KEY,
		PROD.EVT_OBJECT , PROD.RECON_TIX TICKET_ID, TEST.RECON_TIX STAGING_TICKET, N''changesNotInManifest'' CHANGE_SUMMARY
		FROM
		(SELECT AUTOiD, row_number() over (partition by HOST_NAME,EVT_NAME,EVT_OBJECT,RECON_TIX order by HOST_NAME,EVT_NAME,EVT_OBJECT,RECON_TIX) ID,S.HOST_NAME, S.AGENTGUID, S.EVT_NAME,S.EVT_DISPLAY_KEY, S.EVT_OBJECT, S.RECON_TIX FROM dbo.SCOR_EVENTS S
		) PROD
		INNER JOIN SCOR_RECON_TICKET2 TIX ON PROD.RECON_TIX = TIX.TICKET_ID AND TIX.STAGING_TICKET IS NOT NULL
		INNER JOIN
		(SELECT AUTOiD, row_number() over (partition by HOST_NAME,EVT_NAME,EVT_OBJECT,RECON_TIX order by HOST_NAME,EVT_NAME,EVT_OBJECT,RECON_TIX) ID,S.HOST_NAME, S.EVT_NAME,S.EVT_DISPLAY_KEY, S.EVT_OBJECT, S.RECON_TIX FROM dbo.SCOR_EVENTS S) TEST
		ON PROD.ID=TEST.ID AND PROD.EVT_NAME = TEST.EVT_NAME AND ISNULL(PROD.EVT_OBJECT,'''') = ISNULL(TEST.EVT_OBJECT,'''') AND TIX.STAGING_TICKET = TEST.RECON_TIX
		UNION
		SELECT DISTINCT TEST.AUTOID, TEST.ID, PROD.HOST_NAME PRODUCTION_SERVER, PROD.AGENTGUID, TEST.HOST_NAME TEST_SERVER, TEST.EVT_NAME, TEST.EVT_DISPLAY_KEY,
		TEST.EVT_OBJECT , PROD.RECON_TIX TICKET_ID, TEST.RECON_TIX STAGING_TICKET, N''changesNotFromManifest'' CHANGE_SUMMARY
		FROM
		(SELECT AUTOiD, row_number() over (partition by HOST_NAME,EVT_NAME,EVT_OBJECT,RECON_TIX order by HOST_NAME,EVT_NAME,EVT_OBJECT,RECON_TIX) ID,S.HOST_NAME, S.EVT_NAME,S.EVT_DISPLAY_KEY, S.EVT_OBJECT, S.RECON_TIX FROM dbo.SCOR_EVENTS S
		) TEST
		INNER JOIN SCOR_RECON_TICKET2 TIX ON TEST.RECON_TIX = TIX.STAGING_TICKET AND TIX.STAGING_TICKET IS NOT NULL
		INNER JOIN
		(SELECT DISTINCT row_number() over (partition by HOST_NAME,EVT_NAME,EVT_OBJECT,RECON_TIX order by HOST_NAME,EVT_NAME,EVT_OBJECT,RECON_TIX) ID,S.HOST_NAME, S.AGENTGUID, S.RECON_TIX FROM dbo.SCOR_EVENTS S) PROD
		ON TIX.TICKET_ID = PROD.RECON_TIX
		EXCEPT
		SELECT TEST.AUTOID, PROD.ID ,PROD.HOST_NAME PRODUCTION_SERVER, PROD.AGENTGUID, TEST.HOST_NAME TEST_SERVER, PROD.EVT_NAME, PROD.EVT_DISPLAY_KEY,
		PROD.EVT_OBJECT , PROD.RECON_TIX TICKET_ID, TEST.RECON_TIX STAGING_TICKET, N''changesNotFromManifest'' CHANGE_SUMMARY
		FROM
		(SELECT AUTOiD, row_number() over (partition by HOST_NAME,EVT_NAME,EVT_OBJECT,RECON_TIX order by HOST_NAME,EVT_NAME,EVT_OBJECT,RECON_TIX) ID,S.HOST_NAME, S.AGENTGUID, S.EVT_NAME,S.EVT_DISPLAY_KEY, S.EVT_OBJECT, S.RECON_TIX FROM dbo.SCOR_EVENTS S
		) PROD
		INNER JOIN SCOR_RECON_TICKET2 TIX ON PROD.RECON_TIX = TIX.TICKET_ID AND TIX.STAGING_TICKET IS NOT NULL
		INNER JOIN
		(SELECT AUTOiD, row_number() over (partition by HOST_NAME,EVT_NAME,EVT_OBJECT,RECON_TIX order by HOST_NAME,EVT_NAME,EVT_OBJECT,RECON_TIX) ID,S.HOST_NAME, S.EVT_NAME,S.EVT_DISPLAY_KEY, S.EVT_OBJECT, S.RECON_TIX FROM dbo.SCOR_EVENTS S) TEST
		ON PROD.ID=TEST.ID AND PROD.EVT_NAME = TEST.EVT_NAME AND ISNULL(PROD.EVT_OBJECT,'''') = ISNULL(TEST.EVT_OBJECT,'''') AND TIX.STAGING_TICKET = TEST.RECON_TIX'
	EXEC(@sql)
END
GO

declare @sql nvarchar(max)
IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'SCOR_VW_NON_COMPLIANT_AGENT')
BEGIN
	SET @sql='ALTER VIEW SCOR_VW_NON_COMPLIANT_AGENT AS
		SELECT ParentID, AgentGUID, SolidifierStatus, SolidifierStatusOnReboot, CLIStatus,IntialScanStatus,SoStatus, LicenseChangeControl, LicenseRunControl, activationStatus, memoryProtection, N''CLIStatusRecovered'' as ''NonComplianceType'', N''lockdownCLI'' as pendingAction, N''N'' as compliant, 1 as ''forChangeControl'', 1 as ''forApplicationControl''
		FROM SCOR_VW_STATUS
		WHERE CLIStatus = ''Recovered''
		UNION
		SELECT ParentID, AgentGUID, SolidifierStatus, SolidifierStatusOnReboot, CLIStatus,IntialScanStatus,SoStatus, LicenseChangeControl, LicenseRunControl, activationStatus, memoryProtection, N''solidifierStatusDisabled'' as ''NonComplianceType'', N''enableSystem'' as pendingAction, N''N'' as compliant, 1 as ''forChangeControl'', 1 as ''forApplicationControl''
		FROM SCOR_VW_STATUS
		WHERE SolidifierStatus = ''Disabled'' and SolidifierStatusOnReboot=''Disabled'' and CLIStatus = ''Lockdown''
		UNION
		SELECT ParentID, AgentGUID, SolidifierStatus, SolidifierStatusOnReboot, CLIStatus,IntialScanStatus,SoStatus,LicenseChangeControl, LicenseRunControl, activationStatus, memoryProtection, N''solidifierStatusDisabled'' as ''NonComplianceType'', N''rebootSystem'' as pendingAction, N''N'' as compliant, 1 as ''forChangeControl'', 1 as ''forApplicationControl''
		FROM SCOR_VW_STATUS
		WHERE SolidifierStatus = ''Disabled'' and SolidifierStatusOnReboot in (''Enabled'',''Update'') and CLIStatus = ''Lockdown''
		UNION
		SELECT ParentID, AgentGUID, SolidifierStatus, SolidifierStatusOnReboot, CLIStatus,IntialScanStatus,SoStatus,LicenseChangeControl, LicenseRunControl, activationStatus, memoryProtection, N''updateMode'' as ''NonComplianceType'', N''endUpdate'' as pendingAction, N''N'' as compliant,  1 as ''forChangeControl'', 1 as ''forApplicationControl''
		FROM SCOR_VW_STATUS
		WHERE SolidifierStatus = ''Update'' and SolidifierStatusOnReboot = ''Update'' and SoStatus is null and CLIStatus = ''Lockdown''
		UNION
		SELECT ParentID, AgentGUID, SolidifierStatus, SolidifierStatusOnReboot, CLIStatus,IntialScanStatus,SoStatus,LicenseChangeControl, LicenseRunControl, activationStatus, memoryProtection, N''updateMode'' as ''NonComplianceType'', N''endUpdate'' as pendingAction, N''N'' as compliant,  1 as ''forChangeControl'', 1 as ''forApplicationControl''
		FROM SCOR_VW_STATUS
		WHERE SolidifierStatus = ''Update'' and SolidifierStatusOnReboot = ''Update'' and SoStatus = ''Solidified'' and CLIStatus = ''Lockdown''
		UNION
		SELECT ParentID, AgentGUID, SolidifierStatus, SolidifierStatusOnReboot, CLIStatus,IntialScanStatus,SoStatus,LicenseChangeControl, LicenseRunControl, activationStatus, memoryProtection, N''updateMode'' as ''NonComplianceType'', N''performInitialScan'' as pendingAction, N''N'' as compliant,  1 as ''forChangeControl'', 1 as ''forApplicationControl''
		FROM SCOR_VW_STATUS
		WHERE SolidifierStatus = ''Update'' and SolidifierStatusOnReboot = ''Update'' and SoStatus = ''Unsolidified'' and CLIStatus = ''Lockdown''
		UNION
		SELECT ParentID, AgentGUID, SolidifierStatus, SolidifierStatusOnReboot, CLIStatus,IntialScanStatus,SoStatus,LicenseChangeControl, LicenseRunControl, activationStatus, memoryProtection, N''observationMode'' as ''NonComplianceType'', N''endObserve'' as pendingAction, N''N'' as compliant,  1 as ''forChangeControl'', 1 as ''forApplicationControl''
		FROM SCOR_VW_STATUS
		WHERE SolidifierStatus = ''Observe'' and SolidifierStatusOnReboot = ''Observe'' and CLIStatus = ''Lockdown''
		UNION
		SELECT ParentID, AgentGUID, SolidifierStatus, SolidifierStatusOnReboot, CLIStatus,IntialScanStatus,SoStatus,LicenseChangeControl, LicenseRunControl, activationStatus, memoryProtection, N''limitedFeatureActivation'' as ''NonComplianceType'', N''rebootSystem'' as pendingAction, N''N'' as compliant,  0 as ''forChangeControl'', 1 as ''forApplicationControl''
		FROM SCOR_VW_STATUS
		WHERE SolidifierACClientStatus=''Enabled-Limited'''
	EXEC(@sql)
END
GO

IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'SCOR_VW_OBSERVATION')
BEGIN
exec sp_refreshview 'SCOR_VW_OBSERVATION';
END
GO


IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'SCOR_VW_SA_GROUPED_REQUEST')
BEGIN
exec sp_refreshview 'SCOR_VW_SA_GROUPED_REQUEST';
END
GO


IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'SCOR_VW_SELF_APPROVAL_AUDIT_REPORT')
BEGIN
exec sp_refreshview 'SCOR_VW_SELF_APPROVAL_AUDIT_REPORT';
END
GO

declare @sql nvarchar(max)
IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'SCOR_VW_THROTTLING_STATUS')
BEGIN
	SET @sql='ALTER VIEW SCOR_VW_THROTTLING_STATUS AS
		SELECT ParentID,
		      AgentGUID,
		      ss_status SolidifierStatus,
		      throttling_events_dropped evtDropped,
		      throttling_events_cache_full_percentage evtCacheFullPerc,
		      case 
		            when throttling_events_threshold_hit_time = ''0'' then null
		            when throttling_events_threshold_hit_time is not null then dateadd(ms, cast(throttling_events_threshold_hit_time as bigint)%(3600*24*1000),  dateadd(day, cast(throttling_events_threshold_hit_time as bigint)/(3600*24*1000), ''1970-01-01 00:00:00.0''))
		      end evtThresHitTime,
		      throttling_ob_dropped obDropped,
		      throttling_ob_cache_full_percentage obCacheFullPerc,
		      case 
		            when throttling_ob_threshold_hit_time = ''0'' then null
		            when throttling_ob_threshold_hit_time is not null then dateadd(ms, cast(throttling_ob_threshold_hit_time as bigint)%(3600*24*1000),  dateadd(day, cast(throttling_ob_threshold_hit_time as bigint)/(3600*24*1000), ''1970-01-01 00:00:00.0''))
		      end obThresHitTime,
		      case 
		            when throttling_invdiff_threshold_hit_time = ''0'' then null
		            when throttling_invdiff_threshold_hit_time is not null then dateadd(ms, cast(throttling_invdiff_threshold_hit_time as bigint)%(3600*24*1000),  dateadd(day, cast(throttling_invdiff_threshold_hit_time as bigint)/(3600*24*1000), ''1970-01-01 00:00:00.0''))
		      end invDiffThresHitTime,
		      case
		            when pull_inv_last_access_time = N''val_not_set'' then null
		            when pull_inv_last_access_time = N''reset'' then null
		            when pull_inv_last_access_time = N''default'' then null
		            when pull_inv_last_access_time is not null then dateadd(ms, cast(pull_inv_last_access_time as bigint)%(3600*24*1000),  dateadd(day, cast(pull_inv_last_access_time as bigint)/(3600*24*1000), ''1970-01-01 00:00:00.0''))
		      end invPullLastTime,
		      case 
		            when pull_inv_next_allowed_time = N''now'' then null
		            when pull_inv_next_allowed_time is not null then dateadd(ms, cast(pull_inv_next_allowed_time as bigint)%(3600*24*1000),  dateadd(day, cast(pull_inv_next_allowed_time as bigint)/(3600*24*1000), ''1970-01-01 00:00:00.0''))
		      end invPullNextTime,
		      case 
		            when pull_inv_last_access_time = N''val_not_set'' then N''val_not_set''
		            when pull_inv_last_access_time = N''reset'' then N''reset''
		            when pull_inv_last_access_time = N''default'' then N''default''
		            else null
		      end invPullLastTimeAdv,
		      case 
		            when pull_inv_next_allowed_time = N''now'' then N''now''
		            else null
		      end invPullNextTimeAdv
		FROM SCOR_VW_PROPERTIES_AGENTGUID WHERE ss_status IS NOT NULL;'
	EXEC(@sql)
END
GO

declare @sql nvarchar(max)
IF  EXISTS(SELECT 1 FROM INFORMATION_SCHEMA.COLUMNS WHERE TABLE_NAME = 'SCOR_VW_SA_REQUEST')
BEGIN
	SET @sql='ALTER VIEW SCOR_VW_SA_REQUEST AS
		SELECT
		    CONVERT(nvarchar(10), sagr.AUTO_ID) + ''_'' + CONVERT(nvarchar(10), sareq.AUTO_ID) AS TABLE_ID,
			sagr.AUTO_ID AS GROUPED_AUTO_ID,
			sareq.AUTO_ID,
			sareq.AGENTGUID,
			sareq.HOST_NAME,
			sagr.CHECKSUM,
			sareq.DETECTED_UTC,
			sagr.ACTIVITY,
			sareq.BINARY_BASE_NAME,
			CASE
			    WHEN sareq.IS_NETWORK_PATH = 1
			    THEN sagr.FILE_NAME + ''\'' + sareq.BINARY_BASE_NAME
			    ELSE sagr.FILE_NAME
			END as FILE_NAME,
			sagr.APP_NAME,
			sagr.PREVALANCE,
			sareq.APPROVAL_STATUS,
			sagr.APPROVAL_STATUS_PENDING, 
			sagr.APPROVAL_STATUS_ALLOWED,
			sagr.APPROVAL_STATUS_BANNED, 
			sagr.IS_INSTALLER,
			sagr.BINARY_INFO_ID,
			sagr.BINARY_REPUTATION_ID, 
			sagr.IS_MP_VIOLATION,
			binrep.EFFECTIVE_LEVEL,
			binrep.EFFECTIVE_LEVEL_REASON, 
			cert.ID AS CERT_ID,
			cert.SUBJECT,
			cert.PUBLIC_KEY_HASH,
			cert.CERT_HASH,
			bininfo.CERTIFICATE_STATUS, 
			sagr.USER_COMMENT,
			sagr.BINARY_SHA256,
			epocp.IPV6, 
			epocp.IPXAddress,
			epocp.IPV4x,
			epocp.OSPlatform,
			epocp.OSType,
			epocp.OSVersion, 
			epoln.nodeName,
			epoln.parentid,
			epoln.lastCommSecure,
			epoln.lastUpdate,
			epoln.managedState,
			epoln.tags, 
			epoln.AutoID,
			invapps.APP_DISP_NAME,
			invapps.CUSTOM_TRUST_LEVEL,
			invapps.APP_DISP_VENDOR,
			invapps.APP_DISP_VERSION,
			sareq.PARENT_PROCESS_NAME,
			sareq.USER_NAME,
		    RIGHT(epopp.ProductCode, 3) AS OS_CODE
		FROM SCOR_SA_GROUPED_REQUEST sagr 
		LEFT JOIN SCOR_BINARY_REPUTATION binrep ON sagr.BINARY_REPUTATION_ID = binrep.AUTO_ID
		LEFT JOIN SCOR_COMMON_BINARY_INFO bininfo ON binrep.AUTO_ID = bininfo.BINARY_REPUTATION_ID
		LEFT JOIN SCOR_CERTIFICATE cert ON binrep.CERT_ID = cert.ID
		LEFT JOIN SCOR_SA_REQUEST sareq ON sagr.AUTO_ID = sareq.GROUPED_REQ_ID
		LEFT JOIN EPOLeafNode epoln ON sareq.AGENTGUID = epoln.AgentGUID
		LEFT JOIN EPOComputerProperties epocp ON epoln.AutoID = epocp.ParentID
		LEFT JOIN SCOR_INV_BINARIES invbin ON sagr.BINARY_REPUTATION_ID = invbin.BINARY_REPUTATION_ID AND sareq.BINARY_BASE_NAME = invbin.BINARY_BASE_NAME
		LEFT JOIN SCOR_INV_APPS invapps ON invbin.APP_ID = invapps.APP_ID
		LEFT JOIN EPOProductProperties epopp ON epoln.AutoID = epopp.ParentID
		INNER JOIN SCOR_CUSTOM_PRODUCT_PROPERTIES scpp ON epopp.AutoID = scpp.ParentID
		WHERE EXISTS (SELECT 1 FROM SCOR_SA_RULES WHERE SCOR_SA_RULES.GROUPED_REQ_ID = sagr.AUTO_ID) AND epoln.Type = 1'

	EXEC(@sql)
END
GO