/* Copyright (C) 2014 McAfee, Inc.  All rights reserved.*/
if exists (select 1 from dbo.sysobjects where id = object_id(N'[dbo].[SCOR_DROP_PROCEDURE]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[SCOR_DROP_PROCEDURE];
GO
CREATE PROCEDURE dbo.SCOR_DROP_PROCEDURE
	@procName nvarchar(128)
AS 
BEGIN
	DECLARE @Stmt nvarchar (2048)
	SET @Stmt = 'if exists (select 1 from dbo.sysobjects where id = object_id(N''dbo.'
		+ @procName + ''') and OBJECTPROPERTY(id, N''IsProcedure'') = 1)
			drop procedure dbo.'+ @procName;
	
	EXEC (@Stmt)
END
GO


dbo.SCOR_DROP_PROCEDURE SCOR_DROP_FUNCTION;
GO
CREATE PROCEDURE dbo.SCOR_DROP_FUNCTION
	@funcName nvarchar(128)
AS 
BEGIN
	DECLARE @Stmt nvarchar (2048)
	SET @Stmt = 'if exists (select 1 from dbo.sysobjects where id = object_id(N''dbo.'
		+ @funcName + ''') and  xtype in (N''FN'', N''IF'', N''TF''))
			drop function dbo.'+ @funcName;
	
	EXEC (@Stmt)
END
GO

dbo.SCOR_DROP_FUNCTION SCOR_FN_IS_PARTITIONING_SUPPORTED;
GO

CREATE FUNCTION dbo.SCOR_FN_IS_PARTITIONING_SUPPORTED()
RETURNS bit as
BEGIN

	DECLARE @RET bit;
	SET @RET = 0;	

	DECLARE @editionId int;
	
	DECLARE @enterpriseEditionId int;
	SET @enterpriseEditionId = 1804890536;

	DECLARE @developerEditionId int;
	SET @developerEditionId = -2117995310;

	DECLARE @enterpriseEvaluationId int;
	SET @enterpriseEvaluationId = -610778273;

	SELECT @editionId = cast(SERVERPROPERTY('EditionId') as int);

	IF ((@editionId = @enterpriseEditionId) or (@editionId = @developerEditionId) or (@editionId = @enterpriseEvaluationId)) 
		BEGIN
			SET @RET = 1;
		END;
	RETURN @RET;
END;
GO


dbo.SCOR_DROP_PROCEDURE SCOR_DROP_PARTITION_FUNCTION;
GO
CREATE PROCEDURE dbo.SCOR_DROP_PARTITION_FUNCTION
	@funcName nvarchar(128)
AS 
BEGIN
	if (dbo.SCOR_FN_IS_PARTITIONING_SUPPORTED() = 1)
	BEGIN
		DECLARE @Stmt nvarchar (2048)
		SET @Stmt = 'if exists (select 1 from sys.partition_functions where name= '''
			+ @funcName + ''')
				drop PARTITION FUNCTION '+ @funcName;
		
		EXEC (@Stmt)
	END
END
GO

dbo.SCOR_DROP_PROCEDURE SCOR_DROP_PARTITION_SCHEME;
GO

CREATE PROCEDURE dbo.SCOR_DROP_PARTITION_SCHEME
	@funcName nvarchar(128)
AS 
BEGIN
	if (dbo.SCOR_FN_IS_PARTITIONING_SUPPORTED() = 1)
	BEGIN
		DECLARE @Stmt nvarchar (2048)
		SET @Stmt = 'if exists (select 1 from sys.partition_schemes where name = '''
			+ @funcName + ''')
				drop PARTITION SCHEME '+ @funcName;
		
		EXEC (@Stmt)
	END
END
GO

dbo.SCOR_DROP_PROCEDURE SCOR_DROP_TABLE;
GO
CREATE PROCEDURE dbo.SCOR_DROP_TABLE
	@tableName nvarchar(128)
AS 
BEGIN
	DECLARE @Stmt nvarchar (2048)
	SET @Stmt = 'if exists (select 1 from dbo.sysobjects where id = object_id(N''dbo.'
		+ @tableName + ''') and OBJECTPROPERTY(id, N''IsUserTable'') = 1)
			drop table dbo.'+ @tableName;
	
	EXEC (@Stmt)
END
GO

dbo.SCOR_DROP_PROCEDURE SCOR_DROP_VIEW;
GO
CREATE PROCEDURE dbo.SCOR_DROP_VIEW
	@viewName nvarchar(128)
AS 
BEGIN
	DECLARE @Stmt nvarchar (2048)
	SET @Stmt = 'if exists (select 1 from dbo.sysobjects where id = object_id(N''dbo.'
		+ @viewName + ''') and OBJECTPROPERTY(id, N''IsView'') = 1)
			drop view dbo.'+ @viewName;
	
	EXEC (@Stmt)
END
GO


dbo.SCOR_DROP_FUNCTION SCOR_CHECK_TABLE_EXISTS;
GO
CREATE FUNCTION dbo.SCOR_CHECK_TABLE_EXISTS
     ( @tableName nvarchar(256))
 RETURNS int
 AS
 BEGIN
	declare @result int;
	if exists (select 1 from dbo.sysobjects where id = object_id(@tableName) and OBJECTPROPERTY(id, N'IsUserTable') = 1)
	    set @result = 1;
	else
	    set @result = 0;
        return @result
 END
 GO
 
 dbo.SCOR_DROP_FUNCTION SCOR_CHECK_TEMP_TABLE_EXISTS;
GO
CREATE FUNCTION dbo.SCOR_CHECK_TEMP_TABLE_EXISTS
     ( @tableName nvarchar(256))
 RETURNS int
 AS
 BEGIN
	 declare @result int;
	 IF OBJECT_ID('[tempdb]..'+@tableName) IS NOT NULL 
		    set @result = 1;
		else
		    set @result = 0;
	 return @result
 END
 GO

dbo.SCOR_DROP_FUNCTION SCOR_CHECK_COLUMN_EXISTS;
GO
/* Use this function ALWAYS in conjuction with dbo.SCOR_CHECK_TABLE_EXISTS() (examples: install.sql) 
   The following check for table-existence does not suffice (until the function returns three different values) */
CREATE FUNCTION dbo.SCOR_CHECK_COLUMN_EXISTS
     ( @tableName nvarchar(256), @columnName nvarchar(256))
 RETURNS int
 AS
 BEGIN
	declare @result int;
	SET @result = 0;
	if exists (select 1 from dbo.sysobjects where id = object_id(@tableName) and OBJECTPROPERTY(id, N'IsUserTable') = 1)
	    begin
                if exists (select 1 from sys.syscolumns where name= @columnName and id=object_id(@tableName))
                    SET @result = 1;
            end
        return @result
 END
 GO

dbo.SCOR_DROP_FUNCTION SCOR_CHECK_CONSTRAINT_EXISTS;
GO
CREATE FUNCTION dbo.SCOR_CHECK_CONSTRAINT_EXISTS
     (@constraintName nvarchar(256))
 RETURNS int
 AS
 BEGIN
	declare @result int;
	SET @result = 0;
	if exists (select 1 from dbo.sysobjects where id = object_id(@constraintName) and OBJECTPROPERTY(id, N'IsConstraint') = 1)
 	    set @result = 1;
	else
	    set @result = 0;
    return @result
 END
 GO 
 
dbo.SCOR_DROP_procedure SCOR_DROP_NOT_NAMED_CONSTRAINT;
GO
CREATE procedure dbo.SCOR_DROP_NOT_NAMED_CONSTRAINT
     @tableName nvarchar(128),
     @columnName nvarchar(128),
     @constraintType nvarchar(128)
AS
BEGIN
       declare @ConstraintName nvarchar(128);
       set @ConstraintName =  (select tc.CONSTRAINT_NAME from INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE cc inner join INFORMATION_SCHEMA.TABLE_CONSTRAINTS tc on
cc.CONSTRAINT_NAME=tc.CONSTRAINT_NAME where cc.TABLE_NAME = @tableName and cc.COLUMN_NAME =  @columnName  and tc.CONSTRAINT_TYPE = @constraintType);

IF(@ConstraintName IS NOT NULL)
 begin
 DECLARE @Stmt nvarchar (2048);
  set @stmt = 'ALTER TABLE '+@tableName+' DROP CONSTRAINT '+@ConstraintName;
   exec (@stmt);
 end
END
GO

dbo.SCOR_DROP_FUNCTION SCOR_CHECK_INDEX_EXISTS;
GO
CREATE FUNCTION dbo.SCOR_CHECK_INDEX_EXISTS
     ( @indexName nvarchar(256))
 RETURNS int
 AS
 BEGIN
	declare @result int;
	if exists (select name from sysindexes where name = @indexName)
	    set @result = 1;
	else
	    set @result = 0;
        return @result
 END
 GO

 
dbo.SCOR_DROP_FUNCTION SCOR_CHECK_INDEX_EXISTS_IN_TABLE;
GO
CREATE FUNCTION dbo.SCOR_CHECK_INDEX_EXISTS_IN_TABLE
     (@indexName nvarchar(256), @tableName nvarchar(256))
 RETURNS int
 AS
 BEGIN
		declare @result int;
		if exists (select name from sys.indexes where name = @indexName and object_id = object_id(@tableName))
			set @result = 1;
		else
			set @result = 0;
    return @result
 END
 GO

dbo.SCOR_DROP_PROCEDURE SCOR_CREATE_INDEX_PROC;
GO
CREATE PROCEDURE dbo.SCOR_CREATE_INDEX_PROC
	@tableName nvarchar(256),
	@columnName nvarchar(256),
	@indexName nvarchar(256)
AS 
BEGIN
DECLARE @Stmt nvarchar (2048)
    if(dbo.SCOR_CHECK_COLUMN_EXISTS (@tableName, @columnName) = 1)
        BEGIN
            if not exists (select name from sysindexes where name = @indexName)
	        BEGIN
	            SET @Stmt = 'create index '+ @indexName +' on dbo.'+ @tableName+' ('+ @columnName + ')';	
	            EXEC (@Stmt)
	        END
        END
END
GO


dbo.SCOR_DROP_PROCEDURE SCOR_DROP_INDEX_PROC;
GO
CREATE PROCEDURE dbo.SCOR_DROP_INDEX_PROC
    @tableName nvarchar(256),
    @indexName nvarchar(256)
AS 
BEGIN
DECLARE @Stmt nvarchar (2048)
    if(dbo.SCOR_CHECK_INDEX_EXISTS_IN_TABLE (@indexName, @tableName) = 1)
        BEGIN
            SET @Stmt = 'drop index '+ @indexName+' on dbo.'+ @tableName;
            EXEC (@Stmt)
        END
END
GO

dbo.SCOR_DROP_FUNCTION SCOR_CHECK_IS_NULL;
GO
CREATE FUNCTION dbo.SCOR_CHECK_IS_NULL
     ( @tableName nvarchar(256), @columnName nvarchar(256))
 RETURNS int
 AS
 BEGIN
    declare @result int;
    set @result = 0;
    if(dbo.SCOR_CHECK_COLUMN_EXISTS (@tableName, @columnName) = 1)
    select @result = is_nullable from sys.columns where object_id = OBJECT_ID(@tableName) and name = @columnName;
    return @result
 END
 GO


dbo.SCOR_DROP_PROCEDURE SCOR_ADD_UNIQUE_CONSTRAINT_PROC;
GO
CREATE PROCEDURE dbo.SCOR_ADD_UNIQUE_CONSTRAINT_PROC
	@tableName nvarchar(256),
	@columnName nvarchar(256),
	@constraintName nvarchar(256)
AS 
BEGIN
DECLARE @Stmt nvarchar (2048)
    if(dbo.SCOR_CHECK_COLUMN_EXISTS (@tableName, @columnName) = 1)
        BEGIN
            if not exists (select 1 from dbo.sysobjects where name = @constraintName and xtype = 'UQ')
	        BEGIN
	            SET @Stmt = 'alter table dbo.'+ @tableName+' add constraint '+ @constraintName+' unique ('+ @columnName+')';
	            EXEC (@Stmt)
	        END
	END
END
GO


dbo.SCOR_DROP_PROCEDURE SCOR_DROP_UNIQUE_CONSTRAINT_PROC;
GO
CREATE PROCEDURE dbo.SCOR_DROP_UNIQUE_CONSTRAINT_PROC
    @tableName nvarchar(256),
    @constraintName nvarchar(256)
AS 
BEGIN
DECLARE @Stmt nvarchar (2048)
if(dbo.SCOR_CHECK_TABLE_EXISTS (@tableName) = 1)
        BEGIN
	    if exists (select 1 from dbo.sysobjects where name = @constraintName and xtype = 'UQ')
                BEGIN
	            SET @Stmt = 'alter table dbo.'+ @tableName+' drop constraint '+ @constraintName;
	            EXEC (@Stmt)
                END
	END
END
GO

dbo.SCOR_DROP_FUNCTION SCOR_CHECK_TRIGGER_EXISTS;
GO
CREATE FUNCTION dbo.SCOR_CHECK_TRIGGER_EXISTS
     ( @triggerName nvarchar(256))
 RETURNS int
 AS
 BEGIN
	declare @result int;
	if exists (select 1 from dbo.sysobjects where id = object_id(@triggerName) and OBJECTPROPERTY(id, N'IsTrigger') = 1)
	    set @result = 1;
	else
	    set @result = 0;
        return @result
 END
 GO
 
dbo.SCOR_DROP_FUNCTION SCOR_GENERATE_DATE_RANGE;
GO
CREATE FUNCTION [dbo].[SCOR_GENERATE_DATE_RANGE]
(     
      
      @StartDate              DATETIME,
      @EndDate                DATETIME
)
RETURNS  
@SelectedRange    TABLE 
(IndividualDate DATETIME)
AS 
BEGIN
Declare @date datetime ;
set @date = @StartDate;
while (@date <= @EndDate)
     begin
        INSERT INTO @SelectedRange (IndividualDate)
      		SELECT @date
        set @date = DATEADD(dd, 1, @date);        
     end
      RETURN
END
GO

 
