/* Copyright (C) 2015-2018 McAfee, Inc.  All rights reserved.*/
/* Each view should be dropped first and then created.This is done so as to make the sqls reentrant.
To drop a view the name of the view should be passed to the procedure dbo.SCOR_DROP_VIEW.
*/

/* Creating a properties view that has also the AGENTGUID column */

dbo.SCOR_DROP_VIEW SCOR_VW_PROPERTIES_AGENTGUID
GO
CREATE VIEW [dbo].[SCOR_VW_PROPERTIES_AGENTGUID] AS
	SELECT ELN.AgentGUID, SCPP.*
	FROM SCOR_CUSTOM_PRODUCT_PROPERTIES AS SCPP
	INNER JOIN EPOProductProperties AS EPP ON (SCPP.ParentID = EPP.AutoID)
	INNER JOIN EPOProductFamilies AS EPF ON (EPP.ProductCode = EPF.ProductCode AND EPF.ProductFamily = 'SOLIDCORE')
	INNER JOIN (SELECT AgentGUID, AutoID FROM EPOLeafNode WHERE Type = 1) AS ELN ON (EPP.ParentID = ELN.AutoID)
GO

/*For Solidifier License Report*/

dbo.SCOR_DROP_VIEW SCOR_VW_LICENSE;
GO
CREATE VIEW [dbo].[SCOR_VW_LICENSE] AS
	SELECT  ParentID,
		AgentGUID,
		'license_change_control' as 'LicenseType'
		FROM SCOR_VW_PROPERTIES_AGENTGUID
		WHERE license_change_control is NOT NULL
		UNION
	SELECT  ParentID,AgentGUID, 'license_runtime_control' as 'LicenseType'
		FROM SCOR_VW_PROPERTIES_AGENTGUID
		WHERE license_runtime_control is NOT NULL
GO

/*For Solidifier Status Report*/

dbo.SCOR_DROP_VIEW SCOR_VW_STATUS;
GO
CREATE VIEW [dbo].[SCOR_VW_STATUS] AS
SELECT ParentID,
	AgentGUID,
 	ss_status SolidifierStatus,
	ss_status_on_reboot SolidifierStatusOnReboot,
	cli_access CLIStatus,
	license_change_control LicenseChangeControl,
	license_runtime_control LicenseRunControl,	
	initial_scan_status IntialScanStatus,
	so_status SoStatus,
	act_status activationStatus,
	mp_status memoryProtection,
	case when ss_status='Enabled' then 
		case
			when act_status ='Full' or act_status is null then 'Enabled-Full'
			when act_status ='Limited' then 'Enabled-Limited' end			
		else ss_status end SolidifierClientStatus,
		
	-- For Application Control license, when activation statue limited, show status as Enable limited 
	case 
		when license_runtime_control is not null then 
		case 
			when ss_status='Enabled' then
			case 
				when act_status ='Full' or act_status is null then 'Enabled-Full'
				when act_status ='Limited' then 'Enabled-Limited' end		
			else ss_status end 
		else null end SolidifierACClientStatus,
		
	-- For Change Control license		
	case 
		when license_change_control is not null then ss_status
		else null end SolidifierCCClientStatus,
	reboot_required_for_uninstall RebootRequiredForUninstall,
	build_status BuildStatus,
	build_validation_status BuildValidationStatus,
	upgrade_status UpgradeStatus,
	DEP Dep,
	ASLR Aslr,
	szProductVer SolidcoreVersion,
	service_status SolidcoreServiceStatus,
	[tie-reputation] TieReputation,
	[gti-reputation] GtiReputation,
	IsATDSubmissionAllowed AtdSubmission
FROM SCOR_VW_PROPERTIES_AGENTGUID
WHERE ss_status IS NOT NULL;
GO

/*For Solidifier Features Status Report*/
/* Putting [] brackects around some columns , as these are the properties coming from end-point. To make the code clean they cannot send underscore. Some how SQL server crib if we do not put bracket on column names having dash */
dbo.SCOR_DROP_VIEW SCOR_FEATURES_STATUS;
GO
CREATE VIEW [dbo].[SCOR_FEATURES_STATUS] AS
SELECT ParentID,
	AgentGUID,
	ss_status SolidifierStatus,
 	mp_status memoryProtection,
 	[mp-casp] mpcasp,
 	[mp-nx] mpnx,
 	[mp-vasr] mpvasr,
 	[self-approval] selfApproval,
 	activex activex,
 	[execution-control] executionControl,
 	[ob-logging] obLogging,
 	[pkg-ctrl] pkgctrl,
	[sau] sau	
FROM SCOR_VW_PROPERTIES_AGENTGUID WHERE ss_status IS NOT NULL;
GO

dbo.SCOR_DROP_VIEW SCOR_VW_NON_COMPLIANT_AGENT;
GO
CREATE VIEW [dbo].[SCOR_VW_NON_COMPLIANT_AGENT] AS
		SELECT ParentID, AgentGUID, SolidifierStatus, SolidifierStatusOnReboot, CLIStatus,IntialScanStatus,SoStatus, LicenseChangeControl, LicenseRunControl, activationStatus, memoryProtection, 'CLIStatusRecovered' as 'NonComplianceType', 'lockdownCLI' as pendingAction, 'N' as compliant, 1 as 'forChangeControl', 1 as 'forApplicationControl'
		FROM SCOR_VW_STATUS
		WHERE CLIStatus = 'Recovered'
		UNION
		SELECT ParentID, AgentGUID, SolidifierStatus, SolidifierStatusOnReboot, CLIStatus,IntialScanStatus,SoStatus, LicenseChangeControl, LicenseRunControl, activationStatus, memoryProtection, 'solidifierStatusDisabled' as 'NonComplianceType', 'enableSystem' as pendingAction, 'N' as compliant, 1 as 'forChangeControl', 1 as 'forApplicationControl'
		FROM SCOR_VW_STATUS
		WHERE SolidifierStatus = 'Disabled' and SolidifierStatusOnReboot='Disabled' and CLIStatus = 'Lockdown'
		UNION
		SELECT ParentID, AgentGUID, SolidifierStatus, SolidifierStatusOnReboot, CLIStatus,IntialScanStatus,SoStatus,LicenseChangeControl, LicenseRunControl, activationStatus, memoryProtection, 'solidifierStatusDisabled' as 'NonComplianceType', 'rebootSystem' as pendingAction, 'N' as compliant, 1 as 'forChangeControl', 1 as 'forApplicationControl'
		FROM SCOR_VW_STATUS
		WHERE SolidifierStatus = 'Disabled' and SolidifierStatusOnReboot in ('Enabled','Update') and CLIStatus = 'Lockdown'
		UNION
		SELECT ParentID, AgentGUID, SolidifierStatus, SolidifierStatusOnReboot, CLIStatus,IntialScanStatus,SoStatus,LicenseChangeControl, LicenseRunControl, activationStatus, memoryProtection, 'updateMode' as 'NonComplianceType', 'endUpdate' as pendingAction, 'N' as compliant,  1 as 'forChangeControl', 1 as 'forApplicationControl'
		FROM SCOR_VW_STATUS
		WHERE SolidifierStatus = 'Update' and SolidifierStatusOnReboot = 'Update' and SoStatus is null and CLIStatus = 'Lockdown'
		UNION
		SELECT ParentID, AgentGUID, SolidifierStatus, SolidifierStatusOnReboot, CLIStatus,IntialScanStatus,SoStatus,LicenseChangeControl, LicenseRunControl, activationStatus, memoryProtection, 'updateMode' as 'NonComplianceType', 'endUpdate' as pendingAction, 'N' as compliant,  1 as 'forChangeControl', 1 as 'forApplicationControl'
		FROM SCOR_VW_STATUS
		WHERE SolidifierStatus = 'Update' and SolidifierStatusOnReboot = 'Update' and SoStatus = 'Solidified' and CLIStatus = 'Lockdown'
		UNION
		SELECT ParentID, AgentGUID, SolidifierStatus, SolidifierStatusOnReboot, CLIStatus,IntialScanStatus,SoStatus,LicenseChangeControl, LicenseRunControl, activationStatus, memoryProtection, 'updateMode' as 'NonComplianceType', 'performInitialScan' as pendingAction, 'N' as compliant,  1 as 'forChangeControl', 1 as 'forApplicationControl'
		FROM SCOR_VW_STATUS
		WHERE SolidifierStatus = 'Update' and SolidifierStatusOnReboot = 'Update' and SoStatus = 'Unsolidified' and CLIStatus = 'Lockdown'
		UNION
		SELECT ParentID, AgentGUID, SolidifierStatus, SolidifierStatusOnReboot, CLIStatus,IntialScanStatus,SoStatus,LicenseChangeControl, LicenseRunControl, activationStatus, memoryProtection, 'observationMode' as 'NonComplianceType', 'endObserve' as pendingAction, 'N' as compliant,  1 as 'forChangeControl', 1 as 'forApplicationControl'
		FROM SCOR_VW_STATUS
		WHERE SolidifierStatus = 'Observe' and SolidifierStatusOnReboot = 'Observe' and CLIStatus = 'Lockdown'
		UNION
		SELECT ParentID, AgentGUID, SolidifierStatus, SolidifierStatusOnReboot, CLIStatus,IntialScanStatus,SoStatus,LicenseChangeControl, LicenseRunControl, activationStatus, memoryProtection, 'limitedFeatureActivation' as 'NonComplianceType', 'rebootSystem' as pendingAction, 'N' as compliant,  0 as 'forChangeControl', 1 as 'forApplicationControl'
		FROM SCOR_VW_STATUS
		WHERE SolidifierACClientStatus='Enabled-Limited'
GO


/* for production server compliance reports */

dbo.SCOR_DROP_VIEW SCOR_VW_CHANGES_IN_MANIFEST;
GO
CREATE VIEW [DBO].[SCOR_VW_CHANGES_IN_MANIFEST] AS
	SELECT DISTINCT EVT.EVT_NAME, EVT.EVT_OBJECT, TIX.*
	FROM DBO.SCOR_EVENTS EVT,
	(SELECT TICKET_ID, STAGING_TICKET FROM DBO.SCOR_RECON_TICKET2 WHERE
		STAGING_TICKET IS NOT NULL) TIX
	WHERE
	EVT.RECON_TIX = TIX.TICKET_ID
	AND EXISTS
	(SELECT 1 FROM DBO.SCOR_EVENTS
		WHERE RECON_TIX = TIX.STAGING_TICKET AND EVT_OBJECT = EVT.EVT_OBJECT AND THREATEVENTID = EVT.THREATEVENTID);
GO


dbo.SCOR_DROP_VIEW SCOR_VW_CHANGES_NOT_IN_MANIFEST;
GO
CREATE VIEW [DBO].[SCOR_VW_CHANGES_NOT_IN_MANIFEST] AS
	SELECT DISTINCT EVT.EVT_NAME, EVT.EVT_OBJECT, TIX.*
	FROM DBO.SCOR_EVENTS EVT,
	(SELECT TICKET_ID, STAGING_TICKET FROM DBO.SCOR_RECON_TICKET2 WHERE
		STAGING_TICKET IS NOT NULL) TIX
	WHERE
	EVT.RECON_TIX = TIX.TICKET_ID
	AND NOT EXISTS
	(SELECT 1 FROM DBO.SCOR_EVENTS
		WHERE RECON_TIX = TIX.STAGING_TICKET AND EVT_OBJECT = EVT.EVT_OBJECT AND THREATEVENTID = EVT.THREATEVENTID);
GO


dbo.SCOR_DROP_VIEW SCOR_VW_CHANGES_NOT_IMPLEMENTED;
GO
CREATE VIEW [DBO].[SCOR_VW_CHANGES_NOT_IMPLEMENTED] AS
	SELECT DISTINCT EVT.EVT_NAME, EVT.EVT_OBJECT, TIX.*
	FROM DBO.SCOR_EVENTS EVT,
	(SELECT TICKET_ID, STAGING_TICKET FROM DBO.SCOR_RECON_TICKET2 WHERE
		STAGING_TICKET IS NOT NULL) TIX
	WHERE
	EVT.RECON_TIX = TIX.STAGING_TICKET
	AND NOT EXISTS
	(SELECT 1 FROM DBO.SCOR_EVENTS
		WHERE RECON_TIX = TIX.TICKET_ID AND EVT_OBJECT = EVT.EVT_OBJECT AND THREATEVENTID = EVT.THREATEVENTID);
GO


/*For Change Management System Compliance Report*/

dbo.SCOR_DROP_VIEW SCOR_VW_CHANGE_MANAGEMENT_COMPLIANCE;
GO
CREATE VIEW [dbo].[SCOR_VW_CHANGE_MANAGEMENT_COMPLIANCE] AS
		SELECT se.AutoID,se.DETECTEDUTC,se.AGENTGUID,se.HOST_NAME,se.EVT_ORIG_USER_NAME,se.EVT_DISPLAY_KEY,se.EVT_PROG_NAME,se.EVT_OBJECT,se.RECON_TIX,CASE WHEN RECON_FLAG=2 OR RECON_FLAG=3 OR RECON_FLAG=6 THEN 'Authorized' WHEN RECON_FLAG=5 OR RECON_FLAG=10 THEN 'Unauthorized' END RECON_STATUS
	FROM SCOR_EVENTS se where RECON_FLAG in (2,3,5,6,10);
GO


dbo.SCOR_DROP_VIEW SCOR_VW_HOST_BINARY_ASSOC_WITH_PATH;
GO
CREATE VIEW [dbo].[SCOR_VW_HOST_BINARY_ASSOC_WITH_PATH] AS
SELECT
	shba.ID,
	sbp.BINARY_PATH,
	shba.EXECUTION_STATUS,
	shba.FETCH_TIME,
	shba.INV_TIME,
	shba.BINARY_ADDITION_TIME,
	shba.IS_ALLOWED_BY_CHECKSUM,
	shba.IS_ALLOWED_BY_CERT,
	shba.IS_ALLOWED_BY_NAME,
	shba.IS_ALLOWED_BY_TRUSTED_PATH,
	shba.IS_SOLIDIFIED,
	shba.IS_UPDATER,
	shba.IS_SYSTEM_FILE,
	shba.BINARY_ID,
	shba.AGENTGUID,
	shba.ROLLUP_TIMESTAMP,
	shba.BINARY_PATH_ID
FROM SCOR_HOST_BINARY_ASSOC shba 
INNER JOIN SCOR_BINARY_PATHS sbp ON shba.BINARY_PATH_ID = sbp.ID
GO

dbo.SCOR_DROP_VIEW SCOR_VW_INVENTORY;
GO
CREATE VIEW [dbo].[SCOR_VW_INVENTORY] AS
SELECT APPS.APP_ID, APPS.APP_NAME, APPS.APP_VERSION, APPS.APP_VENDOR, APPS.APP_DISP_NAME, APPS.APP_DISP_VERSION, APPS.APP_DISP_VENDOR, APPS.CUSTOM_TRUST_LEVEL APP_CUSTOM_TRUST_LEVEL,
BIN.BINARY_ID, BIN.BINARY_EMBED_NAME, BIN.BINARY_EMBED_VERSION, BIN.BINARY_EMBED_APP_NAME, BIN.BINARY_EMBED_APP_VERSION,
BIN.BINARY_EMBED_APP_VENDOR, BIN.BINARY_BASE_NAME, BIN.BINARY_SHA1,BIN.BINARY_SHA256, 
BIN.BINARY_SIZE, BIN.BINARY_TYPE, BIN.IS_INSTALLER, BIN.HAS_CERTS,
BIN.FIRST_SEEN_TIME, BIN.FIRST_SEEN_HOST,
CASE WHEN BIN.APP_ID IS NULL THEN BIN.BINARY_ID ELSE BIN.APP_ID END TEMP_ID,
CASE WHEN BIN.APP_ID IS NULL THEN 'scor.topSystemsWithBadApps.da.otherBinaries' ELSE 'scor.topSystemsWithBadApps.da.applications' END CATEGORY,
REP.GTI_SCORE_MAPPED, REP.GTI_TRUST_LEVEL, REP.EFFECTIVE_LEVEL, 
REP.GTI_IS_INSTALLER, REP.GTI_IS_SYSTEM_FILE,
ASSOC.ID, ASSOC.BINARY_PATH, ASSOC.EXECUTION_STATUS, ASSOC.FETCH_TIME LAST_UPDATED_TIME, ASSOC.IS_ALLOWED_BY_CHECKSUM,
ASSOC.IS_ALLOWED_BY_CERT, ASSOC.IS_ALLOWED_BY_NAME, ASSOC.IS_ALLOWED_BY_TRUSTED_PATH,
ASSOC.IS_SOLIDIFIED, ASSOC.IS_UPDATER, ASSOC.IS_SYSTEM_FILE, ASSOC.AGENTGUID, scorProp.INVENTORY_FETCH_TIME 
FROM [dbo].[SCOR_INV_SYSTEM_PROPERTIES] scorProp
INNER JOIN dbo.SCOR_VW_HOST_BINARY_ASSOC_WITH_PATH ASSOC on (scorProp.AGENTGUID = ASSOC.AGENTGUID)
LEFT OUTER JOIN dbo.SCOR_INV_BINARIES BIN ON (ASSOC.BINARY_ID = BIN.BINARY_ID)
LEFT OUTER JOIN dbo.SCOR_BINARY_REPUTATION REP ON (BIN.BINARY_REPUTATION_ID = REP.AUTO_ID)
LEFT OUTER JOIN dbo.SCOR_INV_APPS APPS ON (BIN.APP_ID = APPS.APP_ID);
GO







dbo.SCOR_DROP_VIEW SCOR_VW_POLICIES_WITH_RULES;
GO
CREATE VIEW [dbo].[SCOR_VW_POLICIES_WITH_RULES] AS
select distinct C.SettingValue ruleType, A.SettingValue filter, B.SettingValue path, T.NAME policyName, T.PolicyDesc policyDesc,min(C.PolicySettingsID) ID
from EPOPolicySettingValues A
    inner join EPOPolicySettingValues B ON A.PolicySettingsId = B.PolicySettingsId AND A.SectionName = B.SectionName
    inner join EPOPolicySettingValues C ON A.PolicySettingsId = C.PolicySettingsId AND A.SectionName = C.SectionName  and A.SettingName = 'action' and B.SettingName = 'pattern'
    and C.SettingName = 'type' and   C.SettingValue !='mon-advanced'
	inner join
    ( select POS.PolicySettingsID, PO.Name, PO.PolicyDesc  from EPOPolicyObjectToSettings POS
                        inner join EPOPolicyObjects PO ON POS.PolicyObjectID = PO.PolicyObjectID
                        inner join EPOPolicyTypes PT ON PO.TypeID = PT.TypeID
                        inner join EPOPolicyProductToTypes PPT ON PT.TypeID = PPT.TypeID
                        where PPT.ProductCode = 'SOLIDCORE_META') T on (A.PolicySettingsID = T.PolicySettingsID)
group by C.SettingValue, A.SettingValue, B.SettingValue, T.NAME, T.PolicyDesc
union
	SELECT 'mon-advanced' ruleType,'exclude' filter,
'( '+T1.[condition-type_0]+' '+T2.[match-type_0]+' '+T3.[pattern_0]+')' +
CASE
	WHEN T1.[condition-type_1] IS NULL
	THEN ' '
	ELSE
	CASE
       WHEN T1.[condition-type_2] IS NULL
       THEN ' AND ( '+T1.[condition-type_1]+' '+T2.[match-type_1]+' '+T3.[pattern_1]+')'
       ELSE
	   CASE
			WHEN T1.[condition-type_3] IS NULL
			THEN ' AND ( '+T1.[condition-type_1]+' '+T2.[match-type_1]+' '+T3.[pattern_1]+')'+' AND ( '+T1.[condition-type_2]+' '+T2.[match-type_2]+' '+T3.[pattern_2]+')'
			ELSE
			CASE
				WHEN T1.[condition-type_4] IS NULL
				THEN ' AND ( '+T1.[condition-type_1]+' '+T2.[match-type_1]+' '+T3.[pattern_1]+')'+' AND ( '+T1.[condition-type_2]+' '+T2.[match-type_2]+' '+T3.[pattern_2]+')' +' AND ( '+T1.[condition-type_3]+' '+T2.[match-type_3]+' '+T3.[pattern_3]+')'
				ELSE
				CASE
					WHEN T1.[condition-type_5] IS NULL
					THEN ' AND ( '+T1.[condition-type_1]+' '+T2.[match-type_1]+' '+T3.[pattern_1]+')'+' AND ( '+T1.[condition-type_2]+' '+T2.[match-type_2]+' '+T3.[pattern_2]+')' +' AND ( '+T1.[condition-type_3]+' '+T2.[match-type_3]+' '+T3.[pattern_3]+')' + ' AND ( '+T1.[condition-type_4]+' '+T2.[match-type_4]+' '+T3.[pattern_4]+')'
					ELSE
					CASE
						WHEN T1.[condition-type_6] IS NULL
						THEN ' AND ( '+T1.[condition-type_1]+' '+T2.[match-type_1]+' '+T3.[pattern_1]+')'+' AND ( '+T1.[condition-type_2]+' '+T2.[match-type_2]+' '+T3.[pattern_2]+')' +' AND ( '+T1.[condition-type_3]+' '+T2.[match-type_3]+' '+T3.[pattern_3]+')' +' AND ( '+T1.[condition-type_4]+' '+T2.[match-type_4]+' '+T3.[pattern_4]+')'+ ' AND ( '+T1.[condition-type_5]+' '+T2.[match-type_5]+' '+T3.[pattern_5]+')'
						ELSE
						CASE
							WHEN T1.[condition-type_7] IS NULL
							THEN ' AND ( '+T1.[condition-type_1]+' '+T2.[match-type_1]+' '+T3.[pattern_1]+')'+' AND ( '+T1.[condition-type_2]+' '+T2.[match-type_2]+' '+T3.[pattern_2]+')' +' AND ( '+T1.[condition-type_3]+' '+T2.[match-type_3]+' '+T3.[pattern_3]+')' +' AND ( '+T1.[condition-type_4]+' '+T2.[match-type_4]+' '+T3.[pattern_4]+')'+ ' AND ( '+T1.[condition-type_5]+' '+T2.[match-type_5]+' '+T3.[pattern_5]+')'  + ' AND ( '+T1.[condition-type_6]+' '+T2.[match-type_6]+' '+T3.[pattern_6]+')'
							ELSE
							CASE
								WHEN T1.[condition-type_8] IS NULL
								THEN ' AND ( '+T1.[condition-type_1]+' '+T2.[match-type_1]+' '+T3.[pattern_1]+')'+' AND ( '+T1.[condition-type_2]+' '+T2.[match-type_2]+' '+T3.[pattern_2]+')' +' AND ( '+T1.[condition-type_3]+' '+T2.[match-type_3]+' '+T3.[pattern_3]+')' +' AND ( '+T1.[condition-type_4]+' '+T2.[match-type_4]+' '+T3.[pattern_4]+')'+ ' AND ( '+T1.[condition-type_5]+' '+T2.[match-type_5]+' '+T3.[pattern_5]+')'  + ' AND ( '+T1.[condition-type_6]+' '+T2.[match-type_6]+' '+T3.[pattern_6]+')' +' AND ( '+T1.[condition-type_7]+' '+T2.[match-type_7]+' '+T3.[pattern_7]+')'
								ELSE
								CASE
									WHEN T1.[condition-type_9] IS NULL
									THEN ' AND ( '+T1.[condition-type_1]+' '+T2.[match-type_1]+' '+T3.[pattern_1]+')'+' AND ( '+T1.[condition-type_2]+' '+T2.[match-type_2]+' '+T3.[pattern_2]+')' +' AND ( '+T1.[condition-type_3]+' '+T2.[match-type_3]+' '+T3.[pattern_3]+')' +' AND ( '+T1.[condition-type_4]+' '+T2.[match-type_4]+' '+T3.[pattern_4]+')'+ ' AND ( '+T1.[condition-type_5]+' '+T2.[match-type_5]+' '+T3.[pattern_5]+')'  + ' AND ( '+T1.[condition-type_6]+' '+T2.[match-type_6]+' '+T3.[pattern_6]+')' +' AND ( '+T1.[condition-type_7]+' '+T2.[match-type_7]+' '+T3.[pattern_7]+')'  + ' AND ( '+T1.[condition-type_8]+' '+T2.[match-type_8]+' '+T3.[pattern_8]+')'
									ELSE ' AND ( '+T1.[condition-type_1]+' '+T2.[match-type_1]+' '+T3.[pattern_1]+')'+' AND ( '+T1.[condition-type_2]+' '+T2.[match-type_2]+' '+T3.[pattern_2]+')' +' AND ( '+T1.[condition-type_3]+' '+T2.[match-type_3]+' '+T3.[pattern_3]+')' +' AND ( '+T1.[condition-type_4]+' '+T2.[match-type_4]+' '+T3.[pattern_4]+')'+ ' AND ( '+T1.[condition-type_5]+' '+T2.[match-type_5]+' '+T3.[pattern_5]+')'  + ' AND ( '+T1.[condition-type_6]+' '+T2.[match-type_6]+' '+T3.[pattern_6]+')' +' AND ( '+T1.[condition-type_7]+' '+T2.[match-type_7]+' '+T3.[pattern_7]+')'  + ' AND ( '+T1.[condition-type_8]+' '+T2.[match-type_8]+' '+T3.[pattern_8]+')'  +' AND ( '+T1.[condition-type_9]+' '+T2.[match-type_9]+' '+T3.[pattern_9]+')'
								END
							END
						END
					END
				END
			END
	   END
    END
END path, T4.NAME policyName, T4.PolicyDesc policyDesc, T4.PolicySettingsID ID
FROM
(SELECT PolicySettingsID, SectionName,action, [condition-type_0],[condition-type_1],[condition-type_2],[condition-type_3],[condition-type_4],[condition-type_5],[condition-type_6],
[condition-type_7],[condition-type_8],[condition-type_9]
FROM (SELECT A.PolicySettingsID, A.SectionName, A.SettingName, A.SettingValue
FROM dbo.EPOPolicySettingValues A ) UP
PIVOT (MIN(SettingValue) FOR SettingName IN
(action,[condition-type_0],[condition-type_1],[condition-type_2],[condition-type_3],[condition-type_4],[condition-type_5],[condition-type_6],
[condition-type_7],[condition-type_8],[condition-type_9])) AS pvt
WHERE [condition-type_0] IS NOT NULL) T1
INNER JOIN
(SELECT PolicySettingsID, SectionName,[match-type_0],[match-type_1],[match-type_2],[match-type_3],[match-type_4],[match-type_5],[match-type_6],
[match-type_7],[match-type_8],[match-type_9]
FROM (SELECT A.PolicySettingsID, A.SectionName, A.SettingName, A.SettingValue
FROM dbo.EPOPolicySettingValues A ) UP
PIVOT (MIN(SettingValue) FOR SettingName IN
([match-type_0],[match-type_1],[match-type_2],[match-type_3],[match-type_4],[match-type_5],[match-type_6],
[match-type_7],[match-type_8],[match-type_9])) AS pvt
WHERE [match-type_0] IS NOT NULL) T2 ON (T1.PolicySettingsID = T2.PolicySettingsID) AND (T1.SectionName = T2.SectionName )
INNER JOIN
(SELECT PolicySettingsID, SectionName,[pattern_0],[pattern_1],[pattern_2],[pattern_3],[pattern_4],[pattern_5],[pattern_6],
[pattern_7],[pattern_8],[pattern_9]
FROM (SELECT A.PolicySettingsID, A.SectionName, A.SettingName, A.SettingValue
FROM dbo.EPOPolicySettingValues A ) UP
PIVOT (MIN(SettingValue) FOR SettingName IN
([pattern_0],[pattern_1],[pattern_2],[pattern_3],[pattern_4],[pattern_5],[pattern_6],
[pattern_7],[pattern_8],[pattern_9])) AS pvt
WHERE [pattern_0] IS NOT NULL) T3
ON (T1.PolicySettingsID = T3.PolicySettingsID) AND (T1.SectionName = T3.SectionName )
INNER JOIN
    ( select POS.PolicySettingsID, PO.Name, PO.PolicyDesc  from EPOPolicyObjectToSettings POS
                        inner join EPOPolicyObjects PO ON POS.PolicyObjectID = PO.PolicyObjectID
                        inner join EPOPolicyTypes PT ON PO.TypeID = PT.TypeID
                        inner join EPOPolicyProductToTypes PPT ON PT.TypeID = PPT.TypeID
                        where PPT.ProductCode = 'SOLIDCORE_META' ) T4 on (T1.PolicySettingsID = T4.PolicySettingsID );
GO


dbo.SCOR_DROP_VIEW SCOR_VW_IMAGE_DEVIATION_HISTORY_DETAILS;
GO
CREATE VIEW [dbo].[SCOR_VW_IMAGE_DEVIATION_HISTORY_DETAILS] AS
SELECT DETAILS.ID,DETAILS.IMAGE_DEV_HISTORY_ID,DETAILS.FILE_PATH, DETAILS.GOLD_FILE_EXECUTION_ALLOWED, DETAILS.TARGET_FILE_EXECUTION_ALLOWED, DETAILS.DEVIATION_TYPE,
APP.APP_DISP_NAME, APP.APP_DISP_VERSION, APP.APP_DISP_VENDOR
FROM dbo.SCOR_IMAGE_DEVIATION_HISTORY_DETAILS DETAILS
INNER JOIN dbo.SCOR_INV_BINARIES BIN ON (DETAILS.TARGET_BINARY_ID = BIN.BINARY_ID)
INNER JOIN dbo.SCOR_INV_APPS APP ON (BIN.APP_ID = APP.APP_ID);
GO

/* For Inventory Age Dashboard */
dbo.SCOR_DROP_VIEW SCOR_VW_INVENTORY_AGE;
GO
CREATE VIEW [dbo].[SCOR_VW_INVENTORY_AGE] AS
SELECT distinct(SYS_PROPS.AGENTGUID) as VW_COL_DISTINCT_AGENTGUID, VW_COL_AGE_CATEGORY =
      CASE 
         WHEN SYS_PROPS.INVENTORY_FETCH_TIME >= (SELECT DATEADD(DAY, -5, GETUTCDATE())) THEN 0
         WHEN SYS_PROPS.INVENTORY_FETCH_TIME < (SELECT DATEADD(DAY, -5, GETUTCDATE())) AND
			SYS_PROPS.INVENTORY_FETCH_TIME >= (SELECT DATEADD(DAY, -15, GETUTCDATE())) THEN 1
         WHEN SYS_PROPS.INVENTORY_FETCH_TIME < (SELECT DATEADD(DAY, -15, GETUTCDATE())) AND
			SYS_PROPS.INVENTORY_FETCH_TIME >= (SELECT DATEADD(DAY, -30, GETUTCDATE())) THEN 2    
         ELSE 3
      END,
      SYS_PROPS.INVENTORY_FETCH_TIME as VW_COL_INV_FETCH_TIME
FROM SCOR_INV_SYSTEM_PROPERTIES SYS_PROPS 
	WHERE SYS_PROPS.INVENTORY_FETCH_STATUS = 2 AND EXISTS ( SELECT 1 FROM EPOLeafNode WHERE SYS_PROPS.AGENTGUID = EPOLeafNode.AGENTGUID);
GO

/* self approval audit report */
dbo.SCOR_DROP_VIEW SCOR_VW_SELF_APPROVAL_AUDIT_REPORT;
GO
CREATE VIEW [dbo].[SCOR_VW_SELF_APPROVAL_AUDIT_REPORT] AS
SELECT
	req.AUTO_ID AS autoId,
	req.DETECTED_UTC AS detectedUtc,
	req.PARENT_PROCESS_NAME AS parentProcName,
	req.ACTIVITY AS activity,
	req.FILES_CHANGED AS filesChanged,
    req.HOST_NAME AS calcHostName,
	req.USER_NAME AS userName,
	req.APPROVAL_STATUS AS approvalStatus,
	req.USERS_COMMENTS AS usersComments,
	CASE WHEN req.EVENT_TYPE = 'ACTX_BLOCKED' THEN req.OBJECT_NAME ELSE req.BINARY_BASE_NAME END AS calcBinaryBaseName,
	bin.BINARY_SHA1 AS binarySha1,
	bin.BINARY_APP_NAME AS binaryAppName,
	cert.PEM AS certificate,
	rep.EFFECTIVE_LEVEL,
	req.AGENTGUID,
	bin.BINARY_SHA256
FROM SCOR_SA_REQUEST req 
INNER JOIN SCOR_COMMON_BINARY_INFO bin ON req.BINARY_INFO_ID = bin.AUTO_ID and req.MODE = 2
LEFT JOIN SCOR_BINARY_REPUTATION rep ON bin.BINARY_SHA1 = rep.SHA1
LEFT JOIN SCOR_CERTIFICATE cert ON bin.PUBLISHER_ID = cert.ID
GO


/* view for PD page using SCOR_SA_GROUPED_REQUEST */
dbo.SCOR_DROP_VIEW SCOR_VW_SA_GROUPED_REQUEST;
GO
CREATE VIEW [dbo].[SCOR_VW_SA_GROUPED_REQUEST] AS
select 
	sagr.AUTO_ID,
	sagr.CHECKSUM,
	sagr.DETECTED_UTC,
	sagr.ACTIVITY,
	sagr.FILE_NAME,
	sagr.APP_NAME,
	sagr.PREVALANCE,
	sagr.APPROVAL_STATUS_PENDING,
	sagr.APPROVAL_STATUS_ALLOWED,
	sagr.APPROVAL_STATUS_BANNED,
	sagr.IS_INSTALLER,
	sagr.BINARY_INFO_ID,
	sagr.BINARY_REPUTATION_ID,
	rep.EFFECTIVE_LEVEL,
	rep.EFFECTIVE_LEVEL_REASON,
	cert.SUBJECT AS ISSUED_TO,
	cert.PUBLIC_KEY_HASH,
	cert.CERT_HASH,
	bin.CERTIFICATE_STATUS,
	sagr.IS_MP_VIOLATION,
	sagr.USER_COMMENT,
	sagr.BINARY_SHA256
FROM SCOR_SA_GROUPED_REQUEST sagr 
LEFT JOIN SCOR_BINARY_REPUTATION rep ON sagr.BINARY_REPUTATION_ID = rep.AUTO_ID
LEFT JOIN SCOR_COMMON_BINARY_INFO bin ON bin.BINARY_REPUTATION_ID = rep.AUTO_ID
LEFT JOIN SCOR_CERTIFICATE cert ON bin.PUBLISHER_ID = cert.ID
where exists (select 1 from SCOR_SA_RULES where  SCOR_SA_RULES.GROUPED_REQ_ID=  sagr.AUTO_ID)
GO	
	



/* START: For Binary Host Stats for cloud feedback */
dbo.SCOR_DROP_VIEW SCOR_VW_BINARY_HOST_STATS;
GO

CREATE VIEW [dbo].[SCOR_VW_BINARY_HOST_STATS] AS
SELECT NODE_STATS.BINARY_SHA1, NODE_COUNT, ISNULL(EXEC_ALLOWED_COUNT, 0) EXEC_ALLOWED_COUNT, ISNULL(SOLIFIED_COUNT, 0) SOLIFIED_COUNT, 
ISNULL(ALLOWED_BY_CERT_COUNT , 0) ALLOWED_BY_CERT_COUNT, ISNULL(ALLOWED_BY_CHECKSUM_COUNT, 0) ALLOWED_BY_CHECKSUM_COUNT, 
ISNULL(BAN_BY_CHECKSUM_COUNT, 0) BAN_BY_CHECKSUM_COUNT, ISNULL(UPDATER_COUNT, 0) UPDATER_COUNT,
ISNULL(SYSTEM_FILE_COUNT, 0) SYSTEM_FILE_COUNT, BINARY_PATH

FROM (SELECT  BINARY_SHA1, COUNT(distinct AGENTGUID) NODE_COUNT from SCOR_INV_BINARIES  SB inner join  
SCOR_HOST_BINARY_ASSOC  on SB.BINARY_ID = SCOR_HOST_BINARY_ASSOC.BINARY_ID group by SB.BINARY_SHA1) NODE_STATS 

left join (select  SB.BINARY_SHA1, COUNT(distinct AGENTGUID) EXEC_ALLOWED_COUNT from dbo.SCOR_HOST_BINARY_ASSOC inner join  
SCOR_INV_BINARIES SB on SB.BINARY_ID = SCOR_HOST_BINARY_ASSOC.BINARY_ID where EXECUTION_STATUS=1
group by SB.BINARY_SHA1) EXECUTION_STATUS_STATS on EXECUTION_STATUS_STATS.BINARY_SHA1 = NODE_STATS.BINARY_SHA1 

left join (select  SB.BINARY_SHA1, COUNT(distinct AGENTGUID) SOLIFIED_COUNT from dbo.SCOR_HOST_BINARY_ASSOC inner join  
SCOR_INV_BINARIES SB on SB.BINARY_ID = SCOR_HOST_BINARY_ASSOC.BINARY_ID where IS_SOLIDIFIED=0
group by SB.BINARY_SHA1) SOLIDIFIED_STATS on NODE_STATS.BINARY_SHA1 = SOLIDIFIED_STATS.BINARY_SHA1 

left join (select  SB.BINARY_SHA1, COUNT(distinct AGENTGUID) ALLOWED_BY_CERT_COUNT from dbo.SCOR_HOST_BINARY_ASSOC inner join  
SCOR_INV_BINARIES SB on SB.BINARY_ID = SCOR_HOST_BINARY_ASSOC.BINARY_ID where IS_ALLOWED_BY_CERT=1
group by SB.BINARY_SHA1) ALLOWED_BY_CERT_STATS on NODE_STATS.BINARY_SHA1 = ALLOWED_BY_CERT_STATS.BINARY_SHA1 

left join (select  SB.BINARY_SHA1, COUNT(distinct AGENTGUID) ALLOWED_BY_CHECKSUM_COUNT from dbo.SCOR_HOST_BINARY_ASSOC inner join  
SCOR_INV_BINARIES SB on SB.BINARY_ID = SCOR_HOST_BINARY_ASSOC.BINARY_ID where IS_ALLOWED_BY_CHECKSUM=1
group by SB.BINARY_SHA1) ALLOWED_BY_CHECKSUM_STATS on NODE_STATS.BINARY_SHA1 = ALLOWED_BY_CHECKSUM_STATS.BINARY_SHA1 

left join (select  SB.BINARY_SHA1, COUNT(distinct AGENTGUID) BAN_BY_CHECKSUM_COUNT from dbo.SCOR_HOST_BINARY_ASSOC inner join  
SCOR_INV_BINARIES SB on SB.BINARY_ID = SCOR_HOST_BINARY_ASSOC.BINARY_ID where IS_ALLOWED_BY_CHECKSUM=0
group by SB.BINARY_SHA1) BAN_BY_CHECKSUM_STATS on NODE_STATS.BINARY_SHA1 = BAN_BY_CHECKSUM_STATS.BINARY_SHA1 

left join (select  SB.BINARY_SHA1, COUNT(distinct AGENTGUID) UPDATER_COUNT from dbo.SCOR_HOST_BINARY_ASSOC inner join  
SCOR_INV_BINARIES SB on SB.BINARY_ID = SCOR_HOST_BINARY_ASSOC.BINARY_ID where IS_UPDATER=1
group by SB.BINARY_SHA1) UPDATER_STATS on NODE_STATS.BINARY_SHA1 = UPDATER_STATS.BINARY_SHA1 

left join (select  SB.BINARY_SHA1, COUNT(distinct AGENTGUID) SYSTEM_FILE_COUNT from dbo.SCOR_HOST_BINARY_ASSOC inner join  
SCOR_INV_BINARIES SB on SB.BINARY_ID = SCOR_HOST_BINARY_ASSOC.BINARY_ID where IS_SYSTEM_FILE=1
group by SB.BINARY_SHA1) SYSTEM_FILE_STATS on NODE_STATS.BINARY_SHA1 = SYSTEM_FILE_STATS.BINARY_SHA1

left join 
(
SELECT BINARY_SHA1, max(BINARY_PATH_I) BINARY_PATH from 
(
select BINARY_SHA1, (select top(1) BINARY_PATH from SCOR_VW_HOST_BINARY_ASSOC_WITH_PATH as ASSOC where ASSOC.BINARY_ID = SBIN.BINARY_ID) as BINARY_PATH_I from SCOR_INV_BINARIES as SBIN 
) as PATHSTATS group by BINARY_SHA1
) as FILE_PATH_STATS ON NODE_STATS.BINARY_SHA1 = FILE_PATH_STATS.BINARY_SHA1;

GO
 
/* End: For Binary Host Stats for cloud feedback */

dbo.SCOR_DROP_VIEW SCOR_VW_EVENT_FEEDBACK_DATA;
GO

CREATE VIEW [dbo].[SCOR_VW_EVENT_FEEDBACK_DATA] AS

SELECT EVT.AUTOID, EVT.AGENTGUID, EVT.EVT_OBJECT, EVT.DETECTEDUTC, EVT.EVT_NAME, max(OBS.BINARY_CKSUM) BINARY_SHA1
FROM SCOR_EVENTS EVT LEFT JOIN SCOR_OBSERVATIONS OBS
ON
EVT.EVT_OBJECT = OBS.BINARY_NAME
AND EVT.AGENTGUID = OBS.AGENTGUID
AND OBS.OBSERVATION_TYPE = EVT.EVT_NAME
WHERE EVT.EVT_NAME IN ('EXECUTION_DENIED', 'PROCESS_HIJACKED', 'NX_VIOLATION_DETECTED')

group by EVT.AutoID, EVT.AGENTGUID, EVT.EVT_OBJECT, EVT.DETECTEDUTC, EVT.EVT_NAME
;
GO

dbo.SCOR_DROP_VIEW SCOR_VW_INV_APPS;
GO
CREATE VIEW [dbo].[SCOR_VW_INV_APPS] AS
select * from SCOR_INV_APPS;
GO

dbo.SCOR_DROP_VIEW SCOR_VW_INV_BINARIES;
GO
CREATE VIEW [dbo].[SCOR_VW_INV_BINARIES] AS
select * from SCOR_INV_BINARIES;
GO

dbo.SCOR_DROP_VIEW SCOR_VW_HOST_BINARY_ASSOC;
GO
CREATE VIEW [dbo].[SCOR_VW_HOST_BINARY_ASSOC] AS
SELECT * FROM SCOR_VW_HOST_BINARY_ASSOC_WITH_PATH;
GO

dbo.SCOR_DROP_VIEW SCOR_VW_BINARY_AVAILABILITY_BY_TYPE;
GO
CREATE VIEW [dbo].[SCOR_VW_BINARY_AVAILABILITY_BY_TYPE] AS
select BINARY_TYPE, isnull(KNOWN_GOOD_BAD, 0) as KNOWN_GOOD_BAD, isnull(KNOWN_UNKNOWN, 0) as KNOWN_UNKNOWN, ISNULL(NOT_KNOWN_TO_CLOUD, 0) as NOT_KNOWN_TO_CLOUD from
(
select BINARY_TYPE,
case when REP.GTI_TRUST_LEVEL in (0,2) then 'KNOWN_GOOD_BAD'
when REP.GTI_TRUST_LEVEL = 1 and GTI_SCORE_MAPPED is not null then 'KNOWN_UNKNOWN'
when REP.GTI_TRUST_LEVEL = 1 and GTI_SCORE_MAPPED is null then 'NOT_KNOWN_TO_CLOUD' end as cloud_status,
COUNT(1) as binary_count
from SCOR_INV_BINARIES 
LEFT OUTER JOIN dbo.SCOR_BINARY_REPUTATION REP ON (SCOR_INV_BINARIES.BINARY_REPUTATION_ID = REP.AUTO_ID)
where REP.GTI_TTL_EXPIRY_UTC is not null group by BINARY_TYPE, REP.GTI_TRUST_LEVEL, REP.GTI_SCORE_MAPPED 
) b

pivot(
max(b.binary_count)
for b.cloud_status in (KNOWN_GOOD_BAD, KNOWN_UNKNOWN, NOT_KNOWN_TO_CLOUD)
)
as pvt;
GO

dbo.SCOR_DROP_VIEW SCOR_VW_APP_AVAILABILITY;
GO
CREATE VIEW [dbo].[SCOR_VW_APP_AVAILABILITY] AS
select GOOD_OR_BAD_APPS, UNKNOWN_APPS FROM 
(select case
when CUSTOM_TRUST_LEVEL in (0, 2) then 'GOOD_OR_BAD_APPS'
WHEN CUSTOM_TRUST_LEVEL = 1 THEN 'UNKNOWN_APPS' END as APP_STATUS,
COUNT(1) as APP_COUNT
FROM SCOR_INV_APPS GROUP BY CUSTOM_TRUST_LEVEL
) apps

pivot (
max(apps.app_count)
for APP_STATUS in (GOOD_OR_BAD_APPS, UNKNOWN_APPS)
)
as pvt;
GO

dbo.SCOR_DROP_VIEW SCOR_VW_THROTTLING_STATUS;
GO
CREATE VIEW [dbo].[SCOR_VW_THROTTLING_STATUS] AS
SELECT ParentID,
      AgentGUID,
      ss_status SolidifierStatus,
      throttling_events_dropped evtDropped,
      throttling_events_cache_full_percentage evtCacheFullPerc,
      case 
            when throttling_events_threshold_hit_time = '0' then null
            when throttling_events_threshold_hit_time is not null then dateadd(ms, cast(throttling_events_threshold_hit_time as bigint)%(3600*24*1000),  dateadd(day, cast(throttling_events_threshold_hit_time as bigint)/(3600*24*1000), '1970-01-01 00:00:00.0'))
      end evtThresHitTime,
      throttling_ob_dropped obDropped,
      throttling_ob_cache_full_percentage obCacheFullPerc,
      case 
            when throttling_ob_threshold_hit_time = '0' then null
            when throttling_ob_threshold_hit_time is not null then dateadd(ms, cast(throttling_ob_threshold_hit_time as bigint)%(3600*24*1000),  dateadd(day, cast(throttling_ob_threshold_hit_time as bigint)/(3600*24*1000), '1970-01-01 00:00:00.0'))
      end obThresHitTime,
      case 
            when throttling_invdiff_threshold_hit_time = '0' then null
            when throttling_invdiff_threshold_hit_time is not null then dateadd(ms, cast(throttling_invdiff_threshold_hit_time as bigint)%(3600*24*1000),  dateadd(day, cast(throttling_invdiff_threshold_hit_time as bigint)/(3600*24*1000), '1970-01-01 00:00:00.0'))
      end invDiffThresHitTime,
      case
            when pull_inv_last_access_time = 'val_not_set' then null
            when pull_inv_last_access_time = 'reset' then null
            when pull_inv_last_access_time = 'default' then null
            when pull_inv_last_access_time is not null then dateadd(ms, cast(pull_inv_last_access_time as bigint)%(3600*24*1000),  dateadd(day, cast(pull_inv_last_access_time as bigint)/(3600*24*1000), '1970-01-01 00:00:00.0'))
      end invPullLastTime,
      case 
            when pull_inv_next_allowed_time = 'now' then null
            when pull_inv_next_allowed_time is not null then dateadd(ms, cast(pull_inv_next_allowed_time as bigint)%(3600*24*1000),  dateadd(day, cast(pull_inv_next_allowed_time as bigint)/(3600*24*1000), '1970-01-01 00:00:00.0'))
      end invPullNextTime,
      case 
            when pull_inv_last_access_time = 'val_not_set' then 'val_not_set'
            when pull_inv_last_access_time = 'reset' then 'reset'
            when pull_inv_last_access_time = 'default' then 'default'
            else null
      end invPullLastTimeAdv,
      case 
            when pull_inv_next_allowed_time = 'now' then 'now'
            else null
      end invPullNextTimeAdv
      
FROM SCOR_VW_PROPERTIES_AGENTGUID WHERE ss_status IS NOT NULL;
GO

dbo.SCOR_DROP_VIEW SCOR_VW_DATA_CONJESTION_STATUS;
GO
CREATE VIEW [dbo].[SCOR_VW_DATA_CONJESTION_STATUS] AS
	SELECT AutoID,DETECTEDUTC, EVT_OBJECT, evt_value1,
	case
			when EVT_VALUE1 = 1  then 1
			when EVT_VALUE1 = 2  then 2
			when EVT_VALUE1 >= 3  and EVT_VALUE1 <= 100 then 3			
		else 0 end ConjestionStatus
		
	FROM 
	(
		SELECT ROW_NUMBER() over (order by allEvents.IndividualDate) AS AutoId, allEvents.IndividualDate as detectedutc, allEvents.evt_object, MAX( allEvents.evt_value1) evt_value1
		FROM
			(
			select *, 'SCORInventory' as evt_object, 0 as evt_value1  from SCOR_GENERATE_DATE_RANGE( DateAdd(yy, -1, convert(VARCHAR(10),GetUTCDate(),112)), convert(VARCHAR(10),GetUTCDate(),112)) 
			union 
			select *, 'SCORObservation' as evt_object, 0 as evt_value1  from SCOR_GENERATE_DATE_RANGE( DateAdd(yy, -1, convert(VARCHAR(10),GetUTCDate(),112)), convert(VARCHAR(10),GetUTCDate(),112)) 
			union
			select *, 'SCORCommandResponse' as evt_object, 0 as evt_value1  from SCOR_GENERATE_DATE_RANGE(  DateAdd(yy, -1, convert(VARCHAR(10),GetUTCDate(),112)), convert(VARCHAR(10),GetUTCDate(),112))
			union
			select *, 'SCORSelfApproval' as evt_object, 0 as evt_value1  from SCOR_GENERATE_DATE_RANGE( DateAdd(yy, -1, convert(VARCHAR(10),GetUTCDate(),112)), convert(VARCHAR(10),GetUTCDate(),112)) 
			
			union 
			
			SELECT  MAX( CONVERT(VARCHAR(10),DETECTEDUTC,112)) detectedutc1, EVT_OBJECT, max(CAST(EVT_VALUE1 AS Int)) EVT_VALUE1 from
				 dbo.SCOR_EVENTS  where threateventid in (20954,20955) and CONVERT(VARCHAR(10),DETECTEDUTC,112)< convert(VARCHAR(10),GetUTCDate(),112) group by EVT_OBJECT, CONVERT(VARCHAR(10),detectedutc,112) 
			
			union 
			
			SELECT top 1 convert(VARCHAR(10),GetUTCDate(),112) todaysDate, EVT_OBJECT, CAST(EVT_VALUE1 AS Int) EVT_VALUE1 from SCOR_EVENTS
					where DETECTEDUTC >= DATEADD(day, -1, GetUTCDate()) and threateventid in (20954,20955) and EVT_OBJECT='SCORInventory'
					order by DETECTEDUTC desc
			union
			SELECT top 1 convert(VARCHAR(10),GetUTCDate(),112) todaysDate, EVT_OBJECT, CAST(EVT_VALUE1 AS Int) EVT_VALUE1 from SCOR_EVENTS
					where DETECTEDUTC >= DATEADD(day, -1, GetUTCDate()) and threateventid in (20954,20955) and EVT_OBJECT='SCORObservation'
					order by DETECTEDUTC desc
			union
			SELECT top 1 convert(VARCHAR(10),GetUTCDate(),112) todaysDate, EVT_OBJECT, CAST(EVT_VALUE1 AS Int) EVT_VALUE1 from SCOR_EVENTS
					where DETECTEDUTC >= DATEADD(day, -1, GetUTCDate()) and threateventid in (20954,20955) and EVT_OBJECT='SCORCommandResponse'
					order by DETECTEDUTC desc
			union
			SELECT top 1 convert(VARCHAR(10),GetUTCDate(),112) todaysDate, EVT_OBJECT, CAST(EVT_VALUE1 AS Int) EVT_VALUE1 from SCOR_EVENTS
					where DETECTEDUTC >= DATEADD(day, -1, GetUTCDate()) and threateventid in (20954,20955) and EVT_OBJECT='SCORSelfApproval'
					order by DETECTEDUTC desc
				 ) allEvents
				 
	 	group by EVT_OBJECT, allEvents.IndividualDate 

	) events
GO

dbo.SCOR_DROP_VIEW SCOR_VW_SCOR_SA_REQUEST;
GO
CREATE VIEW [dbo].[SCOR_VW_SCOR_SA_REQUEST] AS
SELECT SCOR_SA_REQUEST.AUTO_ID,SCOR_SA_REQUEST.APPROVAL_STATUS,SCOR_SA_REQUEST.DETECTED_UTC,
CASE 
	WHEN SCOR_SA_REQUEST.EVENT_TYPE = 'ACTX_BLOCKED' OR SCOR_SA_REQUEST.EVENT_TYPE = 'ACTX_INSTALL_PREVENTED' OR SCOR_SA_REQUEST.IS_NETWORK_PATH = 'TRUE' THEN SCOR_SA_REQUEST.OBJECT_NAME 
	ELSE SCOR_SA_REQUEST.BINARY_BASE_NAME END OBJECT_NAME
FROM dbo.SCOR_SA_REQUEST
GO

/* View for new Policy Discovery page */
dbo.SCOR_DROP_VIEW SCOR_VW_SA_REQUEST;
GO
CREATE VIEW [dbo].[SCOR_VW_SA_REQUEST] AS
SELECT
    CONVERT(varchar(10), sagr.AUTO_ID) + '_' + CONVERT(varchar(10), sareq.AUTO_ID) AS TABLE_ID,
	sagr.AUTO_ID AS GROUPED_AUTO_ID,
	sareq.AUTO_ID,
	sareq.AGENTGUID,
	sareq.HOST_NAME,
	sagr.CHECKSUM,
	sareq.DETECTED_UTC,
	sagr.ACTIVITY,
	sareq.BINARY_BASE_NAME,
	CASE
	    WHEN sareq.IS_NETWORK_PATH = 1
	    THEN sagr.FILE_NAME + '\' + sareq.BINARY_BASE_NAME
	    ELSE sagr.FILE_NAME
	END as FILE_NAME,
	sagr.APP_NAME,
	sagr.PREVALANCE,
	sareq.APPROVAL_STATUS,
	sagr.APPROVAL_STATUS_PENDING, 
	sagr.APPROVAL_STATUS_ALLOWED,
	sagr.APPROVAL_STATUS_BANNED, 
	sagr.IS_INSTALLER,
	sagr.BINARY_INFO_ID,
	sagr.BINARY_REPUTATION_ID, 
	sagr.IS_MP_VIOLATION,
	binrep.EFFECTIVE_LEVEL,
	binrep.EFFECTIVE_LEVEL_REASON, 
	cert.ID AS CERT_ID,
	cert.SUBJECT,
	cert.PUBLIC_KEY_HASH,
	cert.CERT_HASH,
	bininfo.CERTIFICATE_STATUS, 
	sagr.USER_COMMENT,
	sagr.BINARY_SHA256,
	epocp.IPV6, 
	epocp.IPXAddress,
	epocp.IPV4x,
	epocp.OSPlatform,
	epocp.OSType,
	epocp.OSVersion, 
	epoln.nodeName,
	epoln.parentid,
	epoln.lastCommSecure,
	epoln.lastUpdate,
	epoln.managedState,
	epoln.tags,
	epoln.AutoID,
	invapps.APP_DISP_NAME,
	invapps.CUSTOM_TRUST_LEVEL,
	invapps.APP_DISP_VENDOR,
	invapps.APP_DISP_VERSION,
	sareq.PARENT_PROCESS_NAME,
	sareq.USER_NAME,
	sareq.EVENT_TYPE,
	sareq.BINARY_PATH,
    RIGHT(epopp.ProductCode, 3) AS OS_CODE
FROM SCOR_SA_GROUPED_REQUEST sagr 
LEFT JOIN SCOR_BINARY_REPUTATION binrep ON sagr.BINARY_REPUTATION_ID = binrep.AUTO_ID
LEFT JOIN SCOR_COMMON_BINARY_INFO bininfo ON binrep.AUTO_ID = bininfo.BINARY_REPUTATION_ID
LEFT JOIN SCOR_CERTIFICATE cert ON binrep.CERT_ID = cert.ID
LEFT JOIN SCOR_SA_REQUEST sareq ON sagr.AUTO_ID = sareq.GROUPED_REQ_ID
LEFT JOIN EPOLeafNode epoln ON sareq.AGENTGUID = epoln.AgentGUID
LEFT JOIN EPOComputerProperties epocp ON epoln.AutoID = epocp.ParentID
LEFT JOIN SCOR_INV_BINARIES invbin ON sagr.BINARY_REPUTATION_ID = invbin.BINARY_REPUTATION_ID AND sareq.BINARY_BASE_NAME = invbin.BINARY_BASE_NAME
LEFT JOIN SCOR_INV_APPS invapps ON invbin.APP_ID = invapps.APP_ID
LEFT JOIN EPOProductProperties epopp ON epoln.AutoID = epopp.ParentID
INNER JOIN SCOR_CUSTOM_PRODUCT_PROPERTIES scpp ON epopp.AutoID = scpp.ParentID
WHERE EXISTS (SELECT 1 FROM SCOR_SA_RULES WHERE SCOR_SA_RULES.GROUPED_REQ_ID = sagr.AUTO_ID) AND epoln.Type = 1
GO



/* View for new Policy Discovery filter page */
dbo.SCOR_DROP_VIEW SCOR_VW_PD_INFO_FILTER;
GO
CREATE VIEW [dbo].[SCOR_VW_PD_INFO_FILTER]
	as (
		 select

						1 as	[AUTO_ID]
				 ,'' as [GROUP]
				 ,'' as [IP_ADDRESS_V4]
				 ,'' as [IP_ADDRESS_V6]
				 ,getdate() as [LAST_COMMUNICATION]
				 ,1 as [MANAGED_STATE]
				 ,OSPlatform  as [OS_PLATFORM]
				 ,OSType as [OS_TYPE]
				 ,OSVersion as [OS_VERSION]
				 ,'' [TAGS]
				 ,'' [USER_NAME]
		 FROM EPOComputerProperties
		 union  ALL
		 SELECT [AUTO_ID]
				 ,[GROUP]
				 ,[IP_ADDRESS_V4]
				 ,[IP_ADDRESS_V6]
				 ,[LAST_COMMUNICATION]
				 ,[MANAGED_STATE]
				 ,[OS_PLATFORM]
				 ,[OS_TYPE]
				 ,[OS_VERSION]
				 ,[TAGS]
				 ,[USER_NAME]
		 FROM [SCOR_PD_FILTER_INFO]
		 union ALL
		 select
						1 as	[AUTO_ID]
				 ,'' as [GROUP]
				 ,'' as [IP_ADDRESS_V4]
				 ,'' as [IP_ADDRESS_V6]
				 ,getdate() as [LAST_COMMUNICATION]
				 ,1 as [MANAGED_STATE]
				 ,'' as [OS_PLATFORM]
				 ,'' as [OS_TYPE]
				 ,'' as [OS_VERSION]
				 ,tags as  [TAGS]
				 ,'' [USER_NAME]
		 from EPOLeafNode
		 )


GO
dbo.SCOR_DROP_VIEW [SCOR_VW_CPE_LATEST_NAMES_AVAILABLE]
GO
CREATE VIEW [dbo].[SCOR_VW_CPE_LATEST_NAMES_AVAILABLE]
	AS
	SELECT
				 [scn].[id]
			,[Name]
			,[import_details_id]
			,[Deprecated]
			,[DeprecatedBy]
			,[DeprecationDate]
			,[cpe23Name]
			,[cpe23DeprecationDate]
			,[cpe23DeprecatedByName]
			,[cpe23DeprecatedType]
			,[cpeAttributePart]
			,[cpeAttributeVendor]
			,[cpeAttributeProduct]
			,[cpeAttributeVersion]
			,[sih].[ImportType]
	FROM
			 SCOR_CPE_NAMES scn
				 INNER JOIN
					 SCOR_IMPORT_DETAILS  sid
					 ON
							 [scn].[import_details_id] = [sid].[id]
				 INNER JOIN
					 SCOR_IMPORT_HISTORY sih
					 ON
							 [sid].[import_id] = [sih].[id]

	WHERE
			Import_details_id IN (
													 SELECT [id]
													 FROM [SCOR_IMPORT_DETAILS]
													 WHERE
															 import_id IN (
																						-- 	Inline view to obtain the latest two successful imports by type
																						SELECT ID FROM (
																													 SELECT TOP(1) [id] FROM [SCOR_IMPORT_HISTORY] WHERE [Status] = 3 AND [ImportType] = 3  -- status Finished, importType = MANAGED CUSTOM CPE
																													 ORDER  BY id DESC) a
																						UNION ALL
																						SELECT ID FROM (
																													 SELECT TOP(1) [id] FROM [SCOR_IMPORT_HISTORY] WHERE [Status] = 3 AND [ImportType] = 1  -- status Finished, importType = CPE GOV DICTIONARY- CANONICAL
																													 ORDER  BY id DESC) a
																						UNION ALL
																						SELECT [ID] FROM (
																														 SELECT   TOP(1)  [id]  FROM scor_import_history WHERE [Status] =3 AND [ImportType] = 2  -- status Finished, importType = CPE CUSTOM DICT
																														 ORDER BY [id] DESC) b
																						)
													 )
		AND	[cpeAttributePart] IN('a')  -- a = application, o = operating system - h=hardware
		AND	[Deprecated] = '0' -- not deprecated cpe
GO
dbo.SCOR_DROP_VIEW [SCOR_VW_CPE_CURRENT_APPLICATIONS]
GO
CREATE VIEW [dbo].[SCOR_VW_CPE_CURRENT_APPLICATIONS]
	AS

		SELECT
					 [AUTO_ID],
					 [CPE_ID],
					 [APP_ID],
					 [APP_NAME],
					 [APP_VERSION],
					 [APP_VENDOR],
					 [APP_DISP_NAME],
					 [APP_DISP_VERSION],
					 [APP_DISP_VENDOR],
					 [CPE_NAME],
					 [FOUND_METHOD]
		FROM
				 [SCOR_CPE_APPS]
		WHERE
				[CPE_NAME] <> ''
GO
dbo.SCOR_DROP_VIEW [SCOR_VW_CPE_INVENTORY_APPS]
GO

CREATE VIEW [dbo].[SCOR_VW_CPE_INVENTORY_APPS]
 as
  SELECT
      [APP_ID],
      [APP_NAME],
      [APP_VENDOR],
      case when [APP_VERSION_CPE] is  null then [APP_VERSION]
        else
        [APP_VERSION_CPE]
        end as  [APP_VERSION],
      case when [APP_VERSION_CPE] is  null then [APP_VERSION]
        else
        [APP_VERSION_CPE]
        end as  [FULL_VERSION]
  FROM
     [SCOR_INV_APPS]



GO

dbo.SCOR_DROP_VIEW [SCOR_VW_CPE_SYSTEMS]
GO
CREATE VIEW [dbo].[SCOR_VW_CPE_SYSTEMS]
	AS
		SELECT DISTINCT
										EPOLeafNode.AutoID,
										EPOLeafNode.NodeName,
										EpoLeafNode.AGENTGUID,
										EPOLeafNode.ParentID,
										SCOR_INV_SYSTEM_PROPERTIES.INVENTORY_FETCH_TIME,
										SCOR_INV_SYSTEM_PROPERTIES.INVENTORY_FETCH_STATUS,
										'' as [ACTIONS]
		FROM
				 EpoLeafNode
					 LEFT JOIN
						 SCOR_HOST_BINARY_ASSOC
						 ON
								 EpoLeafNode.AGENTGUID = SCOR_HOST_BINARY_ASSOC.AGENTGUID
					 LEFT JOIN
						 SCOR_BINARY_PATHS
						 ON
								 SCOR_HOST_BINARY_ASSOC.BINARY_PATH_ID = SCOR_BINARY_PATHS.ID
					 LEFT JOIN
						 SCOR_INV_BINARIES
						 ON
								 SCOR_HOST_BINARY_ASSOC.BINARY_ID = SCOR_INV_BINARIES.BINARY_ID
					 LEFT JOIN
						 SCOR_BINARY_REPUTATION
						 ON
								 SCOR_INV_BINARIES.BINARY_REPUTATION_ID = SCOR_BINARY_REPUTATION.AUTO_ID
					 LEFT JOIN
						 SCOR_CERTIFICATE
						 ON
								 SCOR_BINARY_REPUTATION.CERT_ID = SCOR_CERTIFICATE.ID
					 LEFT JOIN
						 SCOR_CERT_REPUTATION
						 ON
								 SCOR_CERTIFICATE.CERT_REPUTATION_ID = SCOR_CERT_REPUTATION.AUTO_ID
					 LEFT JOIN
						 SCOR_INV_APPS
						 ON
								 SCOR_INV_BINARIES.APP_ID = SCOR_INV_APPS.APP_ID
					 INNER JOIN
						 SCOR_CPE_APPS scpa
						 on
								 SCOR_INV_APPS.APP_ID = scpa.APP_ID
					 LEFT JOIN
						 SCOR_INV_SYSTEM_PROPERTIES
						 ON
								 SCOR_INV_SYSTEM_PROPERTIES.AGENTGUID = EPOLeafNode.AgentGUID
		where
				SCOR_INV_SYSTEM_PROPERTIES.AGENTGUID = EPOLeafNode.AGENTGUID
GO


dbo.SCOR_DROP_VIEW SCOR_VW_CPE_APPS_SYSTEM
GO
CREATE VIEW [dbo].SCOR_VW_CPE_APPS_SYSTEM
  AS
		SELECT DISTINCT
										scpa.AUTO_ID,
										scpa.CPE_ID,
										scpa.APP_ID,
										scpa.APP_NAME,
										scpa.APP_VENDOR,
										scpa.APP_VERSION,
										scpa.CPE_NAME,
										scpa.FOUND_METHOD,
										EpoLeafNode.AGENTGUID

		FROM
				 EpoLeafNode
					 LEFT JOIN
						 SCOR_HOST_BINARY_ASSOC
						 ON
								 EpoLeafNode.AGENTGUID = SCOR_HOST_BINARY_ASSOC.AGENTGUID
					 LEFT JOIN
						 SCOR_BINARY_PATHS
						 ON
								 SCOR_HOST_BINARY_ASSOC.BINARY_PATH_ID = SCOR_BINARY_PATHS.ID
					 LEFT JOIN
						 SCOR_INV_BINARIES
						 ON
								 SCOR_HOST_BINARY_ASSOC.BINARY_ID = SCOR_INV_BINARIES.BINARY_ID
					 LEFT JOIN
						 SCOR_BINARY_REPUTATION
						 ON
								 SCOR_INV_BINARIES.BINARY_REPUTATION_ID = SCOR_BINARY_REPUTATION.AUTO_ID
					 LEFT JOIN
						 SCOR_CERTIFICATE
						 ON
								 SCOR_BINARY_REPUTATION.CERT_ID = SCOR_CERTIFICATE.ID
					 LEFT JOIN
						 SCOR_CERT_REPUTATION
						 ON
								 SCOR_CERTIFICATE.CERT_REPUTATION_ID = SCOR_CERT_REPUTATION.AUTO_ID
					 LEFT JOIN
						 SCOR_INV_APPS
						 ON
								 SCOR_INV_BINARIES.APP_ID = SCOR_INV_APPS.APP_ID
					 INNER JOIN
						 SCOR_CPE_APPS scpa
						 on
								 SCOR_INV_APPS.APP_ID = scpa.APP_ID
					 LEFT JOIN
						 SCOR_INV_SYSTEM_PROPERTIES
						 ON
								 SCOR_INV_SYSTEM_PROPERTIES.AGENTGUID = EPOLeafNode.AgentGUID
		where
				SCOR_INV_SYSTEM_PROPERTIES.AGENTGUID = EPOLeafNode.AGENTGUID
GO
